@@ -563,7 +563,9 @@ calendar_create_print_window (GUI *appGUI)
 	                  G_CALLBACK (window_cal_print_opt_close_cb), appGUI);
 	g_signal_connect (G_OBJECT (appGUI->cal->window_print_options), "key_press_event",
 	                  G_CALLBACK (cal_print_opt_key_press_cb), appGUI);
-	gtk_window_set_transient_for (GTK_WINDOW (appGUI->cal->window_print_options), GTK_WINDOW (appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+		gtk_window_set_transient_for (GTK_WINDOW (appGUI->cal->window_print_options), GTK_WINDOW (appGUI->main_window));
+	}
 	gtk_container_set_border_width (GTK_CONTAINER (appGUI->cal->window_print_options), 4);
 
 	/*---------------------------------------------------------------------------------*/
@@ -868,20 +870,12 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 16);
 
-	if (config.default_stock_icons) {
-		cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-	} else {
-		cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-	}
+	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
 	gtk_widget_show (cancel_button);
 	g_signal_connect (cancel_button, "clicked", G_CALLBACK (window_button_cal_print_opt_close_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 
-	if (config.default_stock_icons) {
-		ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
-	} else {
-		ok_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OK);
-	}
+	ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
 	gtk_widget_show (ok_button);
 	g_signal_connect (ok_button, "clicked", G_CALLBACK (calendar_print_start_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
