@@ -401,8 +401,8 @@ tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 gboolean
 notify_tasks (GUI *appGUI)
 {
-guint32 current_date;
-gint current_time;
+/*guint32 current_date;*/
+/*gint current_time;*/
 
 GtkTreeIter iter;
 TASK_ITEM *item;
@@ -416,8 +416,8 @@ gboolean sound_flag = TRUE;
 	show_postponed_notification (appGUI);
 #endif /* HAVE_LIBNOTIFY */
 
-	current_date = utl_date_get_current_julian ();
-	current_time = utl_time_get_current_seconds ();
+/*	current_date = utl_date_get_current_julian ();*/
+/*	current_time = utl_time_get_current_seconds ();*/
 
 	i = 0;
 
@@ -454,9 +454,17 @@ gboolean sound_flag = TRUE;
 					a->date = 0;
 
 					if (textdesc != NULL)
+#ifdef HAVE_LIBNOTIFY7
+						a->notify = notify_notification_new (item->summary, textdesc, GTK_STOCK_DIALOG_WARNING);
+#else
 						a->notify = notify_notification_new (item->summary, textdesc, GTK_STOCK_DIALOG_WARNING, NULL);
+#endif /* HAVE_LIBNOTIFY7 */
 					else
+#ifdef HAVE_LIBNOTIFY7
+						a->notify = notify_notification_new (item->summary, text, GTK_STOCK_DIALOG_WARNING);
+#else
 						a->notify = notify_notification_new (item->summary, text, GTK_STOCK_DIALOG_WARNING, NULL);
+#endif /* HAVE_LIBNOTIFY7 */
 
 					g_free (textdesc);
 					g_free (text);
@@ -483,8 +491,10 @@ gboolean sound_flag = TRUE;
 #endif /* HAVE_LIBNOTIFY */
 
 					if (gtk_status_icon_get_visible (appGUI->osmo_trayicon)) {
-#ifdef HAVE_LIBNOTIFY
+#ifdef HAVE_LIBNOTIFY 
+#ifndef HAVE_LIBNOTIFY7
 						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
+#endif /* HAVE_LIBNOTIFY7 */
 #endif /* HAVE_LIBNOTIFY */
 				        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
 
@@ -532,9 +542,17 @@ gboolean sound_flag = TRUE;
 					a->time = -1;
 					a->date = 0;
 					if (textdesc != NULL)
+#ifdef HAVE_LIBNOTIFY7
+						a->notify = notify_notification_new (_("Alarm warning!"), textdesc, GTK_STOCK_DIALOG_INFO);
+#else
 						a->notify = notify_notification_new (_("Alarm warning!"), textdesc, GTK_STOCK_DIALOG_INFO, NULL);
+#endif /* HAVE_LIBNOTIFY7 */
 					else
+#ifdef HAVE_LIBNOTIFY7
+						a->notify = notify_notification_new (_("Alarm warning!"), text, GTK_STOCK_DIALOG_INFO);
+#else
 						a->notify = notify_notification_new (_("Alarm warning!"), text, GTK_STOCK_DIALOG_INFO, NULL);
+#endif /* HAVE_LIBNOTIFY7 */
 
 					notify_notification_set_timeout (a->notify, NOTIFY_EXPIRES_NEVER);
 					notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_NORMAL);
@@ -546,7 +564,9 @@ gboolean sound_flag = TRUE;
 
 					if (gtk_status_icon_get_visible (appGUI->osmo_trayicon)) {
 #ifdef HAVE_LIBNOTIFY
+#ifndef HAVE_LIBNOTIFY7
 						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
+#endif /* HAVE_LIBNOTIFY7 */
 #endif /* HAVE_LIBNOTIFY */
 				        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
 
@@ -588,7 +608,9 @@ time_handler (GUI *appGUI)
 static gint minute = -1;
 gint current_minute;
 
-	update_clock (appGUI);
+	if (config.di_show_current_time_seconds == TRUE) {
+		update_clock (appGUI);
+	}
 
     current_minute = get_current_minute ();
 
@@ -613,6 +635,9 @@ gint current_minute;
 				calendar_set_today (appGUI);
 			}
 
+		if (config.di_show_current_time_seconds == FALSE) {
+			update_clock (appGUI);
+		}
 		gui_systray_tooltip_update (appGUI);
 	}
 
