@@ -30,6 +30,8 @@
 #define CONTACTS_ENTRIES_FILENAME   "contacts_records.xml"
 
 #define GOOGLE_MAPS_QUERY           "http://maps.google.com/maps?q="
+#define BING_MAPS_QUERY             "http://www.bing.com/maps/default.aspx?where1="
+#define OSM_MAPS_QUERY              "http://nominatim.openstreetmap.org/search?q="
 
 /* photo widths */
 #define PHOTO_SMALL     80
@@ -44,8 +46,8 @@ enum {
 };
 
 enum {
-	HOME_ADDRESS = 0,
-	WORK_ADDRESS
+    HOME_ADDRESS = 0,
+    WORK_ADDRESS
 };
 
 void        gui_create_contacts                     (GUI *appGUI);
@@ -58,6 +60,7 @@ void        insert_photo                            (gchar *photo_filename, GtkT
 gboolean    check_address                           (gint address_type, GUI *appGUI);
 void        show_contact_location_on_map            (gint address_type, GUI *appGUI);
 void        contacts_selection_activate             (gboolean active, GUI *appGUI);
+gint        query                                   (GUI* appGUI, gchar* matchWith);
 
 #endif /* _CONTACTS_H */
 
