@@ -247,9 +247,9 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
                                         text = NULL;
                                     } else {
                                         if (i == COLUMN_BIRTH_DAY_DATE) {
-                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_FULL, config.override_locale_settings));
+                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_DD_MM_YYYY, TRUE));
                                         } else {
-                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_NAME_DAY, config.override_locale_settings));
+                                            text = g_strdup((const gchar *)julian_to_str(date, DATE_DD_MM_YYYY, TRUE));
                                         }
                                     }
                                 } else {
@@ -479,7 +479,7 @@ gint i;
 
     MESSAGE *msg = (MESSAGE *)user_data;
 
-    i = (int) msg->data;
+    i = (size_t) msg->data;
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(button)) == TRUE) {
         config.export_fields[i] = '+';
@@ -517,7 +517,7 @@ select_action_cb (GtkWidget *widget, gpointer user_data) {
     for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
         if (i != COLUMN_PHOTO && i != COLUMN_ID) {
-                switch((gint) msg->data) {
+                switch((size_t) msg->data) {
 
                     case SELECT_ALL:
                         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(msg->appGUI->cnt->check_buttons[i]), TRUE);
@@ -583,7 +583,9 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
     gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->export_window), 
                                  config.contacts_export_win_w, config.contacts_export_win_h);
 
-    gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->export_window), GTK_WINDOW(appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+        gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->export_window), GTK_WINDOW(appGUI->main_window));
+	}
     gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->export_window), TRUE);
 
     g_signal_connect (G_OBJECT (appGUI->cnt->export_window), "key_press_event", 
@@ -800,7 +802,7 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
 
             gtk_widget_show (appGUI->cnt->check_buttons[i]);
             msg_export_field[i].appGUI = appGUI;
-            msg_export_field[i].data = (gpointer) i;
+            msg_export_field[i].data = (gpointer) ((size_t)i);
             g_signal_connect (G_OBJECT (appGUI->cnt->check_buttons[i]), "toggled",
                               G_CALLBACK (export_field_selected_cb), &msg_export_field[i]);
             GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->check_buttons[i], GTK_CAN_FOCUS);
@@ -814,11 +816,7 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
         }
     }
 
-    if (config.default_stock_icons) {
-        browse_dir_button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
-    } else {
-        browse_dir_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OPEN);
-    }
+	browse_dir_button = utl_gui_create_button (GTK_STOCK_OPEN, OSMO_STOCK_BUTTON_OPEN, _("Browse"));
     gtk_widget_show (browse_dir_button);
     GTK_WIDGET_UNSET_FLAGS(browse_dir_button, GTK_CAN_FOCUS);
     g_signal_connect(browse_dir_button, "clicked", G_CALLBACK(browse_dir_cb), appGUI);
@@ -840,17 +838,13 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-    if (config.default_stock_icons) {
-	    cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-    } else {
-        cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-    }
+	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
     g_signal_connect(cancel_button, "clicked", G_CALLBACK(button_export_window_close_cb), appGUI);
 
-    appGUI->cnt->export_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CONTACTS_EXPORT);
+    appGUI->cnt->export_button = utl_gui_create_button (OSMO_STOCK_BUTTON_CONTACTS_EXPORT, OSMO_STOCK_BUTTON_CONTACTS_EXPORT, _("Export"));
     gtk_widget_show (appGUI->cnt->export_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->cnt->export_button);
     GTK_WIDGET_SET_FLAGS (appGUI->cnt->export_button, GTK_CAN_DEFAULT);
