@@ -21,7 +21,6 @@
 
 #include "contacts_import.h"
 #include "contacts_import_csv.h"
-#include "contacts_import_syncml.h"
 #include "i18n.h"
 #include "utils.h"
 #include "utils_date.h"
@@ -35,46 +34,12 @@
 
 /*-------------------------------------------------------------------------------------*/
 
-void
-import_store_values (GUI *appGUI) {
-
-    config.import_type = gtk_combo_box_get_active (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox));
-
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cnt->bluetooth_radiobutton)) == TRUE) {
-        config.import_interface_type = SYNCML_BLUETOOTH;
-    }
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cnt->usb_radiobutton)) == TRUE) {
-        config.import_interface_type = SYNCML_USB;
-    }
-
-    strncpy(config.import_bluetooth_address, 
-            gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->bluetooth_address_entry)), MAXADDRESS-1);
-
-    config.import_binary_xml = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->cnt->use_wbxml_checkbutton));
-
-    config.import_bluetooth_channel = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cnt->bluetooth_channel_spinbutton)); 
-    config.import_usb_interface = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(appGUI->cnt->usb_interface_spinbutton)); 
-}
-
-/*-------------------------------------------------------------------------------------*/
-
-#ifndef HAVE_LIBSYNCML
 gboolean
 import_contacts_select_file (GUI *appGUI) {
-#else
-void
-import_contacts_select_file_cb (GtkWidget *widget, gpointer user_data) {
-#endif
 
 GtkWidget *dialog;
 GtkFileFilter *filter_1, *filter_2;
-#ifndef HAVE_LIBSYNCML
 gboolean ret = FALSE;
-#endif
-
-#ifdef HAVE_LIBSYNCML
-    GUI *appGUI = (GUI *)user_data;
-#endif
 
     dialog = gtk_file_chooser_dialog_new(_("Select CSV file"),
                                          GTK_WINDOW(appGUI->cnt->import_sel_window),
@@ -102,38 +67,22 @@ gboolean ret = FALSE;
 
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
 
-#ifdef HAVE_LIBSYNCML
-        gtk_widget_hide(dialog);
-
-        gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->input_file_entry), 
-                            gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)));
-
-#else
         gtk_widget_hide(dialog);
         while (g_main_context_iteration(NULL, FALSE));
 
         ret = add_csv_records(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)), appGUI);
-#endif
-
     }
 
     gtk_widget_destroy(dialog);
 
-#ifndef HAVE_LIBSYNCML
     return ret;
-#endif
-
 }
 
 /*-------------------------------------------------------------------------------------*/
 
 gboolean
 import_contacts_from_csv_file (GUI *appGUI) {
-#ifndef HAVE_LIBSYNCML
     return import_contacts_select_file (appGUI);
-#else
-    return FALSE;
-#endif
 }
 
 /*-------------------------------------------------------------------------------------*/
@@ -146,7 +95,7 @@ import_sel_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_da
     gdk_window_get_root_origin (GDK_WINDOW(appGUI->cnt->import_sel_window->window),
                                 &config.contacts_import_sel_win_x, &config.contacts_import_sel_win_y);
 
-    import_store_values (appGUI);
+/*    import_store_values (appGUI);*/
 
     gtk_widget_destroy(appGUI->cnt->import_sel_window);
 }
@@ -192,10 +141,10 @@ gint import_type;
     switch (import_type) {
         case IMPORT_TYPE_FILE:
             gtk_widget_set_sensitive(appGUI->cnt->file_import_vbox, TRUE);
-            gtk_widget_set_sensitive(appGUI->cnt->syncml_import_vbox, FALSE);
+            gtk_widget_set_sensitive(appGUI->cnt->import_vbox, FALSE);
             break;
         case IMPORT_TYPE_SYNCML:
-            gtk_widget_set_sensitive(appGUI->cnt->syncml_import_vbox, TRUE);
+            gtk_widget_set_sensitive(appGUI->cnt->import_vbox, TRUE);
             gtk_widget_set_sensitive(appGUI->cnt->file_import_vbox, FALSE);
             break;
     }
@@ -211,22 +160,6 @@ import_sel_combo_box_focus_cb (GtkWidget *widget, GtkDirectionType *arg1, gpoint
 
 /*------------------------------------------------------------------------------*/
 
-void
-import_sel_interface_changed_cb (GtkButton *button, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cnt->bluetooth_radiobutton)) == TRUE) {
-        gtk_widget_show (appGUI->cnt->bluetooth_params_hbox);
-        gtk_widget_hide (appGUI->cnt->usb_params_hbox);
-    } else {
-        gtk_widget_show (appGUI->cnt->usb_params_hbox);
-        gtk_widget_hide (appGUI->cnt->bluetooth_params_hbox);
-    }
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 import_sel_cb (GtkWidget *widget, gpointer user_data) {
 
@@ -234,7 +167,7 @@ import_sel_cb (GtkWidget *widget, gpointer user_data) {
     gchar *text;
     gchar tmpbuf[BUFFER_SIZE];
 
-    import_store_values (appGUI);
+/*    import_store_values (appGUI);*/
 
     if (config.import_type == IMPORT_TYPE_FILE) {
 
@@ -248,15 +181,6 @@ import_sel_cb (GtkWidget *widget, gpointer user_data) {
             return;
         }
         add_csv_records(text, appGUI);
-
-    } else {
-
-        /* SYNCML */
-
-#ifdef HAVE_LIBSYNCML
-        import_contacts_from_syncml (config.import_interface_type, appGUI);
-#endif
-
     }
 
     import_sel_window_close_cb (NULL, NULL, appGUI);
@@ -276,10 +200,6 @@ GtkWidget *alignment;
 GtkWidget *hbox4;
 GtkWidget *vbox4;
 GtkWidget *hbox6;
-GSList *radiobutton_group = NULL;
-GtkWidget *hbox7;
-GtkObject *bluetooth_channel_spinbutton_adj;
-GtkObject *usb_interface_spinbutton_adj;
 GtkWidget *cancel_button;
 GtkWidget *hbuttonbox;
 gchar tmpbuf[BUFFER_SIZE];
@@ -293,7 +213,9 @@ gchar tmpbuf[BUFFER_SIZE];
                      config.contacts_import_sel_win_x, config.contacts_import_sel_win_y);
     gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->import_sel_window), 450, -1);
 
-    gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->import_sel_window), GTK_WINDOW(appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+        gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->import_sel_window), GTK_WINDOW(appGUI->main_window));
+	}
     gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->import_sel_window), TRUE);
 
     g_signal_connect (G_OBJECT (appGUI->cnt->import_sel_window), "key_press_event", 
@@ -361,10 +283,6 @@ gchar tmpbuf[BUFFER_SIZE];
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->contacts_browse_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->cnt->contacts_browse_button);
     gtk_box_pack_start (GTK_BOX (hbox4), appGUI->cnt->contacts_browse_button, FALSE, TRUE, 4);
-#ifdef HAVE_LIBSYNCML
-    g_signal_connect(appGUI->cnt->contacts_browse_button, "clicked", 
-                     G_CALLBACK(import_contacts_select_file_cb), appGUI);
-#endif
 
     sprintf (tmpbuf, "<b>%s:</b>", _("Input filename"));
     label = gtk_label_new (tmpbuf);
@@ -372,13 +290,13 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    appGUI->cnt->syncml_import_vbox = gtk_vbox_new (FALSE, 0);
-    gtk_widget_show (appGUI->cnt->syncml_import_vbox);
-    gtk_box_pack_start (GTK_BOX (vbox1), appGUI->cnt->syncml_import_vbox, FALSE, FALSE, 0);
+    appGUI->cnt->import_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (appGUI->cnt->import_vbox);
+    gtk_box_pack_start (GTK_BOX (vbox1), appGUI->cnt->import_vbox, FALSE, FALSE, 0);
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->syncml_import_vbox), frame, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (appGUI->cnt->import_vbox), frame, TRUE, TRUE, 0);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
     alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
@@ -394,88 +312,6 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_show (hbox6);
     gtk_box_pack_start (GTK_BOX (vbox4), hbox6, TRUE, TRUE, 2);
 
-    appGUI->cnt->bluetooth_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, "Bluetooth");
-    gtk_widget_show (appGUI->cnt->bluetooth_radiobutton);
-    gtk_box_pack_start (GTK_BOX (hbox6), appGUI->cnt->bluetooth_radiobutton, FALSE, FALSE, 0);
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cnt->bluetooth_radiobutton), radiobutton_group);
-    g_signal_connect (G_OBJECT (appGUI->cnt->bluetooth_radiobutton), "clicked",
-                      G_CALLBACK(import_sel_interface_changed_cb), appGUI);
-    radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cnt->bluetooth_radiobutton));
-
-    appGUI->cnt->usb_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, "USB");
-    gtk_widget_show (appGUI->cnt->usb_radiobutton);
-    gtk_box_pack_start (GTK_BOX (hbox6), appGUI->cnt->usb_radiobutton, FALSE, FALSE, 0);
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cnt->usb_radiobutton), radiobutton_group);
-    radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cnt->usb_radiobutton));
-
-    hbox7 = gtk_hbox_new (FALSE, 8);
-    gtk_widget_show (hbox7);
-    gtk_box_pack_start (GTK_BOX (vbox4), hbox7, TRUE, TRUE, 2);
-
-    appGUI->cnt->bluetooth_params_hbox = gtk_hbox_new (FALSE, 4);
-    gtk_widget_show (appGUI->cnt->bluetooth_params_hbox);
-    gtk_box_pack_start (GTK_BOX (hbox7), appGUI->cnt->bluetooth_params_hbox, TRUE, TRUE, 0);
-
-    sprintf (tmpbuf, "%s:", _("Address"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), label, FALSE, FALSE, 0);
-
-    appGUI->cnt->bluetooth_address_entry = gtk_entry_new ();
-    gtk_widget_show (appGUI->cnt->bluetooth_address_entry);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), appGUI->cnt->bluetooth_address_entry, TRUE, TRUE, 0);
-    gtk_entry_set_max_length (GTK_ENTRY(appGUI->cnt->bluetooth_address_entry), 17);    /* 00:00:00:00:00:00 */
-
-    sprintf (tmpbuf, "%s:", _("Channel"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), label, FALSE, FALSE, 0);
-
-    bluetooth_channel_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
-    appGUI->cnt->bluetooth_channel_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (bluetooth_channel_spinbutton_adj), 1, 0);
-    gtk_widget_show (appGUI->cnt->bluetooth_channel_spinbutton);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->bluetooth_params_hbox), appGUI->cnt->bluetooth_channel_spinbutton, FALSE, FALSE, 0);
-
-    appGUI->cnt->usb_params_hbox = gtk_hbox_new (FALSE, 4);
-    gtk_widget_show (appGUI->cnt->usb_params_hbox);
-    gtk_box_pack_start (GTK_BOX (hbox7), appGUI->cnt->usb_params_hbox, TRUE, TRUE, 0);
-
-    sprintf (tmpbuf, "%s:", _("Interface"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->usb_params_hbox), label, FALSE, FALSE, 0);
-
-    usb_interface_spinbutton_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
-    appGUI->cnt->usb_interface_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (usb_interface_spinbutton_adj), 1, 0);
-    gtk_widget_show (appGUI->cnt->usb_interface_spinbutton);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->usb_params_hbox), appGUI->cnt->usb_interface_spinbutton, FALSE, FALSE, 0);
-
-    sprintf (tmpbuf, "<b>%s</b>", _("Interface"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-
-    frame = gtk_frame_new (NULL);
-    gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (appGUI->cnt->syncml_import_vbox), frame, TRUE, TRUE, 0);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 2, 2, 12, 0);
-
-    appGUI->cnt->use_wbxml_checkbutton = gtk_check_button_new_with_mnemonic (_("Use binary XML (WBXML)"));
-    gtk_widget_show (appGUI->cnt->use_wbxml_checkbutton);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->cnt->use_wbxml_checkbutton);
-
-    sprintf (tmpbuf, "<b>%s</b>", _("Options"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
@@ -502,72 +338,10 @@ gchar tmpbuf[BUFFER_SIZE];
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->cnt->import_type_combobox), config.import_type);
 
-    if (config.import_interface_type == 0) {    /* bluetooth */
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->cnt->bluetooth_radiobutton), TRUE);
-    } else {
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->cnt->usb_radiobutton), TRUE);
-    }
-    import_sel_interface_changed_cb (GTK_BUTTON(appGUI->cnt->bluetooth_radiobutton), appGUI);
-
-    gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->bluetooth_address_entry), 
-                        config.import_bluetooth_address);
-
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->cnt->use_wbxml_checkbutton), config.import_binary_xml);
-
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cnt->bluetooth_channel_spinbutton), config.import_bluetooth_channel);
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->cnt->usb_interface_spinbutton), config.import_usb_interface);
-
     gtk_widget_show (appGUI->cnt->import_sel_window);
 
 }
 
-/*-------------------------------------------------------------------------------------*/
-
-/*gboolean*/
-/*import_contacts_from_csv_file (GUI *appGUI) {*/
-
-/*GtkWidget *dialog;*/
-/*gboolean ret = FALSE;*/
-/*GtkFileFilter *filter_1, *filter_2;*/
-
-    /*dialog = gtk_file_chooser_dialog_new(_("Select CSV file"),*/
-                                         /*GTK_WINDOW(appGUI->main_window),*/
-                                         /*GTK_FILE_CHOOSER_ACTION_OPEN,*/
-                                         /*GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,*/
-                                         /*GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,*/
-                                         /*NULL);*/
-
-    /*gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);*/
-    /*gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dialog), FALSE);*/
-    /*gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);*/
-
-    /*filter_1 = gtk_file_filter_new();*/
-    /*gtk_file_filter_add_pattern(filter_1, "*");*/
-    /*gtk_file_filter_set_name(GTK_FILE_FILTER(filter_1), _("All Files"));*/
-    /*gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter_1);*/
-
-    /*filter_2 = gtk_file_filter_new();*/
-    /*gtk_file_filter_add_pattern(filter_2, "*.[cC][sS][vV]");*/
-    /*gtk_file_filter_set_name(GTK_FILE_FILTER(filter_2), _("CSV (comma-separated values) files (*.csv)"));*/
-    /*gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter_2);*/
-
-    /*gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter_2);*/
-
-
-    /*if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {*/
-
-        /*gtk_widget_hide(dialog);*/
-        /*while (g_main_context_iteration(NULL, FALSE));*/
-
-        /*ret = add_csv_records(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog)), appGUI);*/
-
-    /*}*/
-
-    /*gtk_widget_destroy(dialog);*/
-
-    /*return ret;*/
-/*}*/
-
 /*------------------------------------------------------------------------------*/
 
 void
@@ -653,7 +427,7 @@ gint i, k, n;
 
     MESSAGE *msg = (MESSAGE *)user_data;
 
-    n = (gint)msg->data;
+    n = (size_t)msg->data;
 
     k = gtk_combo_box_get_active (GTK_COMBO_BOX(msg->appGUI->cnt->field_type_comboboxes[n]));
     msg->appGUI->cnt->field_type[n] = k;
@@ -754,13 +528,13 @@ gchar tmpbuf[BUFFER_SIZE];
                             /* convert birth day date field */
                             if (p) {
                                 gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter,
-                                                   appGUI->cnt->field_type[i]-1, str_to_julian(field_str, DATE_FULL), -1);
+                                                   appGUI->cnt->field_type[i]-1, str_to_julian(field_str, DATE_DD_MM_YYYY), -1);
                             }
                         } else if (appGUI->cnt->field_type[i]-1 == COLUMN_NAME_DAY_DATE) {
                             /* convert name day date field */
                             if (p) {
                                 gtk_list_store_set(appGUI->cnt->contacts_list_store, &iter,
-                                                   appGUI->cnt->field_type[i]-1, str_to_julian(field_str, DATE_NAME_DAY), -1);
+                                                   appGUI->cnt->field_type[i]-1, str_to_julian(field_str, DATE_DD_MM_YYYY), -1);
                             }
                         } else if (p) {
                             /* remaining fields */
@@ -935,7 +709,9 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                 gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->import_window), 
                                              config.contacts_import_win_w, config.contacts_import_win_h);
 
-                gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->import_window), GTK_WINDOW(appGUI->main_window));
+				if (config.fullscreen == FALSE) {
+                    gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->import_window), GTK_WINDOW(appGUI->main_window));
+				}
                 gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->import_window), TRUE);
 
                 g_signal_connect (G_OBJECT (appGUI->cnt->import_window), "key_press_event", 
@@ -1107,7 +883,7 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                     appGUI->cnt->field_type[i] = 0;
                     gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (appGUI->cnt->field_type_comboboxes[i]), 4);
 
-                    msg_fields[i].data = (gpointer)i;
+                    msg_fields[i].data = (gpointer)((size_t)i);
                     msg_fields[i].appGUI = appGUI;
                     g_signal_connect (G_OBJECT (appGUI->cnt->field_type_comboboxes[i]), "changed", 
                                       G_CALLBACK(type_changed_cb), &msg_fields[i]);
