@@ -89,6 +89,9 @@ static void
 ci_font_size_changed_cb (GtkSpinButton *spinbutton, GUI *appGUI)
 {
 	config.contact_item_font_size = (gint) gtk_spin_button_get_value (spinbutton);
+#ifdef HAVE_LIBWEBKIT
+	g_object_set (appGUI->cnt->webkit_settings, "default-font-size", config.contact_item_font_size, NULL);
+#endif  /* LIBWEBKIT */
 	g_signal_emit_by_name (G_OBJECT (appGUI->cnt->contacts_list_selection), "changed");
 }
 
@@ -201,10 +204,21 @@ contacts_hide_group_column_changed_cb (GtkToggleButton *widget, GUI *appGUI)
 
 /* ========================================================================== */
 
+static void
+maps_provider_changed_cb (GtkComboBox *widget, GUI *appGUI)
+{
+    config.maps_provider = gtk_combo_box_get_active (widget);
+}
+
+/* ========================================================================== */
+
 static void
 create_miscellaneous_section (GtkWidget *miscellaneous_vbox, GUI *appGUI)
 {
 	GtkWidget *checkbutton;
+	GtkWidget *maps_hbox;
+	GtkWidget *label;
+	GtkWidget *combobox;
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Select and show first item after search"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.show_after_search);
@@ -217,6 +231,20 @@ create_miscellaneous_section (GtkWidget *miscellaneous_vbox, GUI *appGUI)
 	gtk_box_pack_start (GTK_BOX (miscellaneous_vbox), checkbutton, TRUE, TRUE, 4);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (contacts_hide_group_column_changed_cb), appGUI);
 	appGUI->opt->contacts_hide_group_column_checkbutton = checkbutton;
+
+	maps_hbox = gtk_hbox_new (FALSE, 8);
+	gtk_box_pack_start (GTK_BOX (miscellaneous_vbox), maps_hbox, TRUE, TRUE, 4);
+
+    label = utl_gui_create_label ("%s:", _("Maps provider"));
+	gtk_box_pack_start (GTK_BOX (maps_hbox), label, FALSE, FALSE, 0);
+
+	combobox = gtk_combo_box_new_text ();
+	gtk_box_pack_start (GTK_BOX (maps_hbox), combobox, FALSE, FALSE, 0);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Google");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "Bing");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), "OpenStreetMap");
+	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (maps_provider_changed_cb), appGUI);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.maps_provider);
 }
 
 /* ========================================================================== */
