@@ -59,6 +59,14 @@ struct  osmo_prefs              config;
 
 /*------------------------------------------------------------------------------*/
 
+void
+gui_quit_osmo_cb (GtkComboBox *widget, GUI *appGUI) {
+	gui_quit_osmo (appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
+
 void
 gui_save_data_and_run_command (gchar *command, GUI *appGUI) {
     gui_save_all_data (appGUI);
@@ -121,12 +129,25 @@ gui_toggle_window_visibility (GUI *appGUI) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+gui_toggle_fullscreen (GUI *appGUI) {
+	if (config.fullscreen == FALSE) {
+		gtk_window_fullscreen (GTK_WINDOW(appGUI->main_window));
+		config.fullscreen = TRUE;
+	} else {
+		gtk_window_unfullscreen (GTK_WINDOW(appGUI->main_window));
+		config.fullscreen = FALSE;
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 gui_quit_osmo (GUI *appGUI) {
 
 #ifdef NOTES_ENABLED
     if (appGUI->nte->editor_active == TRUE) {
-        g_signal_emit_by_name (G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
+		editor_close_cb (NULL, appGUI);
     }
 #endif  /* NOTES_ENABLED */
 
@@ -170,8 +191,10 @@ gui_quit_osmo (GUI *appGUI) {
         gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(appGUI->cal->notes_button), FALSE);
 
         if (appGUI->window_visible == TRUE) {
-            gtk_window_get_size (GTK_WINDOW(appGUI->main_window),
-                                &config.window_size_x, &config.window_size_y);
+			if (!config.fullscreen) {
+				gtk_window_get_size (GTK_WINDOW(appGUI->main_window),
+									&config.window_size_x, &config.window_size_y);
+			}
         }
     } 
 
@@ -675,7 +698,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 	                return FALSE;
                 case GDK_y:
                     key_counter_add (26, appGUI);
-                    return TRUE;
+                    return FALSE;
                 case GDK_l:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + l */
                         gtk_widget_grab_focus(GTK_WIDGET(appGUI->tsk->tasks_find_entry));
@@ -870,14 +893,14 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 
                 case GDK_w:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + w */
-                        g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
+						editor_close_cb (NULL, appGUI);
                         return TRUE;
                     }
                     return FALSE;
 
                 case GDK_Escape:
 					if (appGUI->nte->find_hbox_visible == FALSE) {
-	                    g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
+						editor_close_cb (NULL, appGUI);
                         return TRUE;
 					}
                     return FALSE;
@@ -919,21 +942,21 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 
                 case GDK_s:
                     if ((event->state & GDK_CONTROL_MASK) && !appGUI->nte->note_read_only) {  /* CTRL + s */
-                        g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/save")), "clicked");
-                        return TRUE;
+						editor_save_buffer_cb (NULL, appGUI);
+						return TRUE;
                     }
                     return FALSE;
 
                 case GDK_f:
                     if (event->state & GDK_CONTROL_MASK) {  /* CTRL + f */
-                        g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/find")), "clicked");
+						editor_find_text_show_cb (NULL, appGUI);
                         return TRUE;
                     }
                     return FALSE;
 
                 case GDK_n:
                     if ((event->state & GDK_CONTROL_MASK) && !appGUI->nte->note_read_only) {  /* CTRL + n */
-                        g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/clear")), "clicked");
+						clear_text_attributes_cb (NULL, appGUI);
                         return TRUE;
                     }
                     return FALSE;
@@ -1012,7 +1035,11 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 1 */
 #if defined(TASKS_ENABLED) || defined(CONTACTS_ENABLED) || defined(NOTES_ENABLED)
                 if (event->state & GDK_CONTROL_MASK) {  /* CTRL + ALT + 1 */
-                    g_signal_emit_by_name(G_OBJECT(appGUI->opt->hide_calendar_checkbutton), "clicked");
+					opt_hide_modules (!config.hide_calendar, 
+									  config.hide_tasks, 
+									  config.hide_contacts, 
+									  config.hide_notes, 
+									  FALSE, appGUI);
                     select_tab (0, appGUI);
                 } else {
 #endif
@@ -1030,7 +1057,11 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 2 */
 #ifdef TASKS_ENABLED
                 if (event->state & GDK_CONTROL_MASK) {  /* CTRL + ALT + 2 */
-                    g_signal_emit_by_name(G_OBJECT(appGUI->opt->hide_tasks_checkbutton), "clicked");
+					opt_hide_modules (config.hide_calendar, 
+									  !config.hide_tasks, 
+									  config.hide_contacts, 
+									  config.hide_notes, 
+									  FALSE, appGUI);
                     select_tab (0, appGUI);
                 } else {
 #endif  /* TASKS_ENABLED */
@@ -1048,7 +1079,11 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 3 */
 #ifdef CONTACTS_ENABLED
                 if (event->state & GDK_CONTROL_MASK) {  /* CTRL + ALT + 3 */
-                    g_signal_emit_by_name(G_OBJECT(appGUI->opt->hide_contacts_checkbutton), "clicked");
+					opt_hide_modules (config.hide_calendar, 
+									  config.hide_tasks, 
+									  !config.hide_contacts, 
+									  config.hide_notes, 
+									  FALSE, appGUI);
                     select_tab (0, appGUI);
                 } else {
 #endif  /* CONTACTS_ENABLED */
@@ -1066,7 +1101,11 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
             if ((event->state & GDK_MOD1_MASK)) {  /* ALT + 4 */
 #ifdef NOTES_ENABLED
                 if (event->state & GDK_CONTROL_MASK) {  /* CTRL + ALT + 4 */
-                    g_signal_emit_by_name(G_OBJECT(appGUI->opt->hide_notes_checkbutton), "clicked");
+					opt_hide_modules (config.hide_calendar, 
+									  config.hide_tasks, 
+									  config.hide_contacts, 
+									  !config.hide_notes, 
+									  FALSE, appGUI);
                     select_tab (0, appGUI);
                 } else {
 #endif  /* NOTES_ENABLED */
@@ -1083,6 +1122,10 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
         case GDK_F6:
 			gtk_widget_show (GTK_WIDGET(opt_create_about_window (appGUI)));
             return TRUE;
+
+		case GDK_F11:   /* full screen */
+			gui_toggle_fullscreen (appGUI);
+            return TRUE;
     }
 
     return FALSE;
@@ -1097,7 +1140,7 @@ notebook_sw_cb (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gp
 
 #ifdef NOTES_ENABLED
 	if (appGUI->nte->editor_active == TRUE) {
-		g_signal_emit_by_name(G_OBJECT(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/close")), "clicked");
+		editor_close_cb (NULL, appGUI);
 	}
 #endif  /* NOTES_ENABLED */
 
@@ -1450,7 +1493,6 @@ gui_create_window (GUI *appGUI)
 	GdkScreen *screen;
 	gint sw, sh;
 	GdkPixbuf *icon;
-	gchar tmpbuf[BUFFER_SIZE];
 
 #ifdef CONTACTS_ENABLED
     appGUI->cnt->contacts_filter_disabled = TRUE;
@@ -1463,8 +1505,7 @@ gui_create_window (GUI *appGUI)
 
     appGUI->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-	g_snprintf (tmpbuf, BUFFER_SIZE, "Osmo %d.%d.%d", VERSION_MAJOR, VERSION_MINOR, VERSION_MICRO);
-    gtk_window_set_title (GTK_WINDOW (appGUI->main_window), tmpbuf);
+	gtk_window_set_title (GTK_WINDOW (appGUI->main_window), "Osmo " VERSION_MAJOR "." VERSION_MINOR "." VERSION_MICRO);
 
    	gtk_widget_set_events(appGUI->main_window, GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 
@@ -1569,7 +1610,8 @@ gui_create_window (GUI *appGUI)
 
 #ifdef TASKS_ENABLED
         read_tasks_entries (appGUI);
-        apply_task_attributes (appGUI);
+		set_categories (appGUI);
+		refresh_tasks (appGUI);
 #endif  /* TASKS_ENABLED */
 
 #ifdef CONTACTS_ENABLED
@@ -1616,6 +1658,25 @@ gui_create_window (GUI *appGUI)
 
     update_aux_calendars (appGUI);
 
+	if (config.toolbar_exit_button == FALSE) {
+        if (appGUI->calendar_only == FALSE) {
+			gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->cal->calendar_uim_widget, "/toolbar/quit"));
+#ifdef CONTACTS_ENABLED
+			gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/quit"));
+#endif /* CONTACTS_ENABLED */
+#ifdef NOTES_ENABLED
+			gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/quit"));
+#endif /* NOTES_ENABLED */
+#ifdef TASKS_ENABLED
+			gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/quit"));
+#endif /* TASKS_ENABLED */
+		}
+	}
+			
+	if (config.fullscreen == TRUE) {
+		gtk_window_fullscreen (GTK_WINDOW(appGUI->main_window));
+	}
+
     if (appGUI->check_events == TRUE) {
         return create_event_checker_window (appGUI);
     } else {
