@@ -45,7 +45,9 @@
 #include <config.h>
 
 #ifdef CONTACTS_ENABLED
-#include <libgtkhtml/view/htmlview.h>
+#ifdef HAVE_LIBWEBKIT
+#include <webkit/webkit.h>
+#endif  /* LIBWEBKIT */
 #endif  /* CONTACTS_ENABLED */
 
 #ifdef HAVE_LIBNOTIFY
@@ -60,10 +62,6 @@
 
 #define     TRANSLATION_DOMAIN      "osmo"
 
-#define     VERSION_MAJOR           0
-#define     VERSION_MINOR           2
-#define     VERSION_MICRO           8
-
 #define     MAX_MONTHS              12
 #define     MAX_WEEKS               6
 #define     DAYS_PER_WEEK           7
@@ -192,6 +190,7 @@ typedef struct {
     gboolean dont_update;
 
     /* calendar toolbar */
+	GtkUIManager *calendar_uim_widget;
     GtkToolbar *calendar_toolbar;
     GtkBox *vbox;
     PangoFontDescription *fd_cal_font;
@@ -378,6 +377,12 @@ typedef struct {
 	GtkWidget *print_day_num_font_entry;
 	GtkWidget *print_event_font_entry;
 	GtkWidget *print_portrait_radiobutton;
+
+#ifdef HAVE_LIBWEBKIT
+    WebKitWebView *html_webkitview;
+	WebKitWebSettings *webkit_settings;
+#endif  /* LIBWEBKIT */
+
 } CALENDAR;
 
 
@@ -458,6 +463,11 @@ typedef struct {
     GtkWidget *checkb_sound_enable;
     GSList *notifications;
 
+#ifdef HAVE_LIBWEBKIT
+    WebKitWebView *html_webkitview;
+	WebKitWebSettings *webkit_settings;
+#endif  /* LIBWEBKIT */
+
 } TASKS;
 #endif  /* TASKS_ENABLED */
 
@@ -543,12 +553,14 @@ typedef struct {
     gint field_type[CONTACTS_NUM_COLUMNS];
     guint max_fields;
     gchar *file_buffer;
-    guint file_length;
+    gsize file_length;
 
     PangoFontDescription *fd_ai_font;
 
-	GtkWidget *html_view;
-	HtmlDocument *html_document;
+#ifdef HAVE_LIBWEBKIT
+    WebKitWebView *html_webkitview;
+	WebKitWebSettings *webkit_settings;
+#endif  /* LIBWEBKIT */
 
     GtkWidget *input_file_entry;
     GtkWidget *import_type_combobox;
@@ -556,7 +568,7 @@ typedef struct {
     GtkWidget *usb_radiobutton;
     GtkWidget *bluetooth_address_entry;
     GtkWidget *file_import_vbox;
-    GtkWidget *syncml_import_vbox;
+    GtkWidget *import_vbox;
     GtkWidget *bluetooth_params_hbox;
     GtkWidget *usb_params_hbox;
     GtkWidget *bluetooth_channel_spinbutton;
@@ -626,6 +638,9 @@ typedef struct {
     GtkWidget *font_picker;
     GtkWidget *editor_textview;
     GtkWidget *editor_scrolledwindow;
+    GtkWidget *ro_editor_scrolledwindow;
+	GtkWidget *editor_viewport;
+	GtkWidget *ro_editor_viewport;
     gboolean changed;
     gboolean find_next_flag;
     gboolean buffer_check_modify_enable;
@@ -640,6 +655,11 @@ typedef struct {
     GtkWidget *find_case_checkbutton;
     GtkWidget *readonly_checkbutton;
 
+#ifdef HAVE_LIBWEBKIT
+    WebKitWebView *html_webkitview;
+	WebKitWebSettings *webkit_settings;
+#endif  /* LIBWEBKIT */
+
 } NOTES;
 #endif  /* NOTES_ENABLED */
 
@@ -700,6 +720,7 @@ typedef struct {
     GtkWidget *calendar_ical_files_treeview;
     GtkTreeSelection *calendar_ical_files_select;
     GtkWidget *di_show_current_time_checkbutton;
+    GtkWidget *di_show_current_time_seconds_checkbutton;
     GtkWidget *di_show_day_number_checkbutton;
     GtkWidget *di_show_current_day_distance_checkbutton;
     GtkWidget *di_show_marked_days_checkbutton;
@@ -929,6 +950,7 @@ void        gui_add_to_notebook             (GtkWidget *widget, gchar *text, GUI
 void        gui_save_all_data               (GUI *appGUI);
 void        gui_save_data_and_run_command   (gchar *command, GUI *appGUI);
 void        gui_quit_osmo                   (GUI *appGUI);
+void        gui_quit_osmo_cb                (GtkComboBox *widget, GUI *appGUI);
 void        gui_systray_initialize          (GUI *appGUI);
 void        gui_systray_update_icon         (GUI *appGUI);
 void        gui_systray_tooltip_update      (GUI *appGUI);
