@@ -28,6 +28,7 @@
 #include "i18n.h"
 #include "check_events.h"
 #include "options_prefs.h"
+#include "contacts.h"
 
 #ifdef BACKUP_SUPPORT
 #include "backup.h"
@@ -62,20 +63,31 @@ gint response = -1;
 struct flock *s_lock = NULL;
 #endif /* WIN32 */
 int fhandle = 0;
+gchar* output_codeset = NULL;
 
 GOptionContext *cmd_context;
 gboolean cmd_calendar = FALSE;
 gboolean cmd_check_events = FALSE;
 gint cmd_check_ndays_events = 0;
 gchar *cmd_cfg_path = NULL;
+#ifdef CONTACTS_ENABLED
+gchar *cmd_mutt_query = NULL;
+#endif  /* CONTACTS_ENABLED */
+/* FIXME: temporary disabled
 gboolean cmd_tiny_gui = FALSE;
+*/
 
 GOptionEntry cmd_options[] = {
     { "calendar",   'c', 0, G_OPTION_ARG_NONE, &cmd_calendar, N_("Show small calendar window"), NULL  },
     { "check",      'e', 0, G_OPTION_ARG_NONE, &cmd_check_events, N_("Check for events since last run"), NULL  },
     { "days",       'd', 0, G_OPTION_ARG_INT, &cmd_check_ndays_events, N_("Number of days to check forward for events (default: 0)"), NULL  },
-    { "config",     's', 0, G_OPTION_ARG_STRING, &cmd_cfg_path, N_("Set absolute path for settings and data files"), "PATH"  },
+    { "config",     's', 0, G_OPTION_ARG_STRING, &cmd_cfg_path, N_("Set absolute path for settings and data files"), "STRING"  },
+#ifdef CONTACTS_ENABLED
+    { "mutt-query", 'q', 0, G_OPTION_ARG_STRING, &cmd_mutt_query, N_("Match contacts with given string"), "STRING" },
+#endif  /* CONTACTS_ENABLED */
+/* FIXME: temporary disabled
     { "tinygui",    't', 0, G_OPTION_ARG_NONE, &cmd_tiny_gui, N_("Modify GUI to use Osmo on low resolutions"), NULL  },
+*/
     { NULL }
 };
 
@@ -132,16 +144,16 @@ GOptionEntry cmd_options[] = {
     appGUI->trayicon_popup_menu = NULL;
 
     appGUI->calendar_only = FALSE;
-	appGUI->cal->datecal_bio = FALSE;
+    appGUI->cal->datecal_bio = FALSE;
     appGUI->check_events = FALSE;
     appGUI->tiny_gui = FALSE;
     appGUI->save_status = 0;
     appGUI->print_font_size = 10;
-    g_sprintf (appGUI->version, "%02d%02d%02d", VERSION_MAJOR, VERSION_MINOR, VERSION_MICRO);
+    g_sprintf (appGUI->version, "%02d%02d%02d", atoi(VERSION_MAJOR), atoi(VERSION_MINOR), atoi(VERSION_MICRO));
 
-	appGUI->cal->last_selected_year = -1;
-	appGUI->cal->date = utl_date_new_current ();
-	appGUI->about_links_list = NULL;
+    appGUI->cal->last_selected_year = -1;
+    appGUI->cal->date = utl_date_new_current ();
+    appGUI->about_links_list = NULL;
 
 #ifdef TASKS_ENABLED
     appGUI->tsk->next_id = 1;
@@ -157,17 +169,30 @@ GOptionEntry cmd_options[] = {
     appGUI->cnt->contacts_filter_disabled = TRUE;
     appGUI->cnt->export_button = NULL;
     appGUI->cnt->output_file_entry = NULL;
-	appGUI->cnt->write_flag = TRUE;
+    appGUI->cnt->write_flag = TRUE;
 #endif  /* CONTACTS_ENABLED */
 
+    if (!(output_codeset = bind_textdomain_codeset(PACKAGE, NULL))) {
+        output_codeset = g_strdup("UTF-8");
+    } else {
+        output_codeset = g_strdup(output_codeset);
+    }
+
     setlocale (LC_ALL, "");
     bindtextdomain (PACKAGE, LOCALEDIR);
-    bind_textdomain_codeset (PACKAGE, "UTF-8");
+
+    if (bind_textdomain_codeset(PACKAGE, output_codeset) == NULL) {
+        fprintf(stderr, "Error setting gettext output codeset to %s\n", output_codeset);
+        g_free (output_codeset);
+        goto finish;
+    }
+
     textdomain (PACKAGE);
+    g_free (output_codeset);
 
     if (argc == 2 && (!strncmp(argv[1], "--help", 6) || (argv[1][0] == '-' && argv[1][1] == '?'))) {
         fprintf(stderr, "\nOSMO v%s (%s)\n", VERSION, _("handy personal organizer"));
-        fprintf(stderr, "Copyright (c) 2007-2008 Tomasz Maka <pasp@users.sourceforge.net>\n\n");
+        fprintf(stderr, "Copyright (c) 2007-2011 Tomasz Maka <pasp@users.sourceforge.net>\n\n");
     }
 
     cmd_context = g_option_context_new(NULL);
@@ -179,85 +204,92 @@ GOptionEntry cmd_options[] = {
     appGUI->check_events = cmd_check_events;
     appGUI->check_ndays_events = cmd_check_ndays_events;
     appGUI->config_path = cmd_cfg_path;
+ /* FIXME: temporary disabled
     appGUI->tiny_gui = cmd_tiny_gui;
-
+*/
     if (prefs_get_config_filename (CONFIG_FILENAME, appGUI) == NULL) {
         fprintf(stderr, "%s\n", _("ERROR: Cannot create config files"));
         goto finish;
     }
 
 #if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
-	backup_restore_run (appGUI);
+    backup_restore_run (appGUI);
 #endif  /* BACKUP_SUPPORT & HAVE_LIBGRINGOTTS */
 
 #ifndef WIN32
     s_lock = g_new0 (struct flock, 1);
-	s_lock->l_type = F_WRLCK;
-	s_lock->l_whence = SEEK_SET;
-	s_lock->l_start = 0;
-	s_lock->l_len = 0;
+    s_lock->l_type = F_WRLCK;
+    s_lock->l_whence = SEEK_SET;
+    s_lock->l_start = 0;
+    s_lock->l_len = 0;
 #endif /* WIN32 */
 
     prefs_read_config (appGUI);
 
-  	g_thread_init (NULL);
     gtk_init (&argc, &argv);
 
-	if (appGUI->calendar_only == FALSE) {
+#ifdef CONTACTS_ENABLED
+    if (cmd_mutt_query)
+    {
+        query (appGUI, cmd_mutt_query);
+        goto finish;
+    }
+#endif  /* CONTACTS_ENABLED */
 
-		close(creat(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), S_IRUSR | S_IWUSR));     /* create lock file */
+    if (appGUI->calendar_only == FALSE) {
 
-		fhandle = open(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), O_RDWR);
+        close(creat(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), S_IRUSR | S_IWUSR));     /* create lock file */
+
+        fhandle = open(prefs_get_config_filename (RUN_FLAG_FILE, appGUI), O_RDWR);
 #ifndef WIN32
-		if (fhandle) {
-			if (fcntl(fhandle, F_SETLK, s_lock) == -1) {
-				close (fhandle);
+        if (fhandle) {
+            if (fcntl(fhandle, F_SETLK, s_lock) == -1) {
+                close (fhandle);
 
-				g_snprintf (tmpbuf, BUFFER_SIZE, "%s %s\n\n%s",
-							_("Another copy of OSMO is already running."),
-							_("Simultaneously use two or more copies of OSMO can be a cause of data loss."),
-							_("Do you really want to continue?"));
+                g_snprintf (tmpbuf, BUFFER_SIZE, "%s %s\n\n%s",
+                            _("Another copy of OSMO is already running."),
+                            _("Simultaneously use two or more copies of OSMO can be a cause of data loss."),
+                            _("Do you really want to continue?"));
 
-				info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW_TOPLEVEL, GTK_DIALOG_MODAL,
-													  GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, tmpbuf, NULL);
+                info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW_TOPLEVEL, GTK_DIALOG_MODAL,
+                                                      GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, tmpbuf, NULL);
 
-				gtk_window_set_title(GTK_WINDOW(info_dialog), _("Warning"));
-				gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER);
-				gtk_widget_show (info_dialog);
+                gtk_window_set_title(GTK_WINDOW(info_dialog), _("Warning"));
+                gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER);
+                gtk_widget_show (info_dialog);
 
-				response = gtk_dialog_run(GTK_DIALOG(info_dialog));
-				gtk_widget_destroy(info_dialog);
+                response = gtk_dialog_run(GTK_DIALOG(info_dialog));
+                gtk_widget_destroy(info_dialog);
 
-				if (response == GTK_RESPONSE_NO || response == GTK_RESPONSE_DELETE_EVENT) {
-					goto finish;
-				}
-			}
-		}
+                if (response == GTK_RESPONSE_NO || response == GTK_RESPONSE_DELETE_EVENT) {
+                    goto finish;
+                }
+            }
+        }
 #endif /* WIN32 */
-	}
+    }
 
 
 #ifdef HAVE_LIBNOTIFY
 #ifdef TASKS_ENABLED
-	notify_init("Osmo notification");
+    notify_init("Osmo notification");
 #endif  /* TASKS_ENABLED */
 #endif  /* HAVE_LIBNOTIFY */
 
     if (appGUI->calendar_only != TRUE) {
         /* setup timer at 1000ms (1s) interval */
-		g_timeout_add (1000, (GtkFunction) time_handler, appGUI);
+        g_timeout_add (1000, (GtkFunction) time_handler, appGUI);
     }
 
     config.run_counter++;
 
-	g_snprintf (tmpbuf, BUFFER_SIZE, "Osmo %d.%d.%d", VERSION_MAJOR, VERSION_MINOR, VERSION_MICRO);
-	g_set_application_name (tmpbuf);
-	gtk_window_set_default_icon_name ("osmo");
+    g_set_application_name ("Osmo " VERSION_MAJOR "." VERSION_MINOR "." VERSION_MICRO);
+    gtk_window_set_default_icon_name ("osmo");
 
     if (gui_create_window (appGUI) == TRUE) {
-		gdk_threads_enter ();
-		gtk_main ();
-		gdk_threads_leave ();
+        gdk_threads_enter ();
+        gtk_main ();
+        gdk_threads_leave ();
     }
 
     if (appGUI->calendar_only == FALSE) {
@@ -271,37 +303,39 @@ GOptionEntry cmd_options[] = {
 
     if (fhandle && appGUI->calendar_only == FALSE) {
  #ifndef WIN32
-    	s_lock->l_type = F_UNLCK;
-    	fcntl(fhandle, F_SETLK, s_lock);
+        s_lock->l_type = F_UNLCK;
+        fcntl(fhandle, F_SETLK, s_lock);
  #endif /* WIN32 */
         close (fhandle);
     }
 
 finish:
-	g_date_free (appGUI->cal->date);
-	utl_gui_url_remove_links (&appGUI->about_links_list, NULL);
-	gdk_cursor_unref (appGUI->hand_cursor);
-	gdk_cursor_unref (appGUI->regular_cursor);
-	g_free (opt);
+    g_date_free (appGUI->cal->date);
+    utl_gui_url_remove_links (&appGUI->about_links_list, NULL);
+    if (appGUI->hand_cursor != NULL) {
+        gdk_cursor_unref (appGUI->hand_cursor);
+        gdk_cursor_unref (appGUI->regular_cursor);
+    }
+    g_free (opt);
 
 #ifdef NOTES_ENABLED
-	g_free (nte);
+    g_free (nte);
 #endif  /* NOTES_ENABLED */
 
 #ifdef CONTACTS_ENABLED
-	g_free (cnt);
+    g_free (cnt);
 #endif  /* CONTACTS_ENABLED */
 
 #ifdef TASKS_ENABLED
-	g_free (tsk);
+    g_free (tsk);
 #endif  /* TASKS_ENABLED */
 
-	g_free (cal);
-	g_free (appGUI);
+    g_free (cal);
+    g_free (appGUI);
 #ifndef WIN32
-	g_free (s_lock);
+    g_free (s_lock);
 #endif /* WIN32 */
-	return 0;
+    return 0;
 }
 
 /*------------------------------------------------------------------------------*/
