@@ -20,6 +20,7 @@
  */
 
 #include "about.h"
+#include "backup.h"
 #include "notes.h"
 #include "i18n.h"
 #include "calendar.h"
@@ -33,6 +34,7 @@
 #include "utils_date_time.h"
 #include "utils_gui.h"
 #include "stock_icons.h"
+#include "gtksourceiter.h"
 
 #ifdef NOTES_ENABLED
 
@@ -44,6 +46,7 @@
 #include <gtkspell/gtkspell.h>
 #endif /* HAVE_GTKSPELL */
 
+
 /*============================================================================*/
 
 static void
@@ -88,7 +91,7 @@ gchar tmpbuf[BUFFER_SIZE];
 		appGUI->nte->editor_active = FALSE;
 
 	} else if (mode == EDITOR) {
-
+    
 		gtk_widget_hide (appGUI->nte->find_hbox);
 		gtk_widget_hide (appGUI->nte->vbox_selector);
 		gtk_widget_show (appGUI->nte->vbox_editor);
@@ -144,6 +147,10 @@ gchar tmpbuf[BUFFER_SIZE];
 		gtk_widget_set_sensitive (appGUI->nte->font_picker, !readonly);
 		appGUI->nte->note_read_only = readonly;
 
+#ifdef HAVE_LIBWEBKIT
+		update_readonly_view (appGUI);
+#endif  /* HAVE_LIBWEBKIT */
+
     }
 }
 
@@ -244,6 +251,7 @@ GtkTreePath *path, *sort_path, *filter_path;
 gint response, line;
 GtkTextMark *cursor;
 gchar tmpbuf[BUFFER_SIZE];
+GtkClipboard *clipboard;
 
 	GUI *appGUI = (GUI *)user_data;
 
@@ -272,6 +280,15 @@ gchar tmpbuf[BUFFER_SIZE];
 		appGUI->nte->keyholder = NULL;
 		grg_context_free (appGUI->nte->context);
 		appGUI->nte->context = NULL;
+
+		/* clear clipboards for encrypted notes */
+		clipboard = gtk_clipboard_get(GDK_SELECTION_PRIMARY);                                                            
+		gtk_clipboard_clear(clipboard);                                                                                  
+		gtk_clipboard_set_text(clipboard, "", 0);                                                                        
+
+		clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);                                                          
+		gtk_clipboard_clear(clipboard);                                                                                
+		gtk_clipboard_set_text(clipboard, "", 0);
 	}
 #endif /* HAVE_LIBGRINGOTTS */
 
@@ -658,79 +675,126 @@ notes_item_selected (GtkTreeSelection *selection, gpointer data) {
 /*------------------------------------------------------------------------------*/
 
 void
-find (gchar *find_text, GtkTextIter *iter, GUI *appGUI) {
+find (gchar *find_text, GtkTextIter *iter, gboolean forward, GUI *appGUI) {
 
 GtkTextBuffer *buffer;
 GtkTextIter match_start, match_end;
 GtkTextMark *found_pos;
-gchar c;
-gint i;
+gboolean flags, result;
 
     if (strlen(find_text)) {
 
-        if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->nte->find_case_checkbutton)) == FALSE) {
-            i = 0;
-            while((c = find_text[i])) {
-                find_text[i++] =  g_unichar_tolower (c);
-            }
-        }
+#ifdef HAVE_LIBWEBKIT
 
-        buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+		if (iter == NULL) { /* webkit */
+	
+			flags = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->nte->find_case_checkbutton));
+            result = webkit_web_view_search_text (WEBKIT_WEB_VIEW (appGUI->nte->html_webkitview),
+                                                  find_text, flags, forward, TRUE);
+			if (result) {
+				utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_OK, appGUI);
+			} else {
+				utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_FAIL, appGUI);
+			}
 
-        if (gtk_text_iter_forward_search (iter, find_text, GTK_TEXT_SEARCH_TEXT_ONLY, 
-                                          &match_start, &match_end, NULL)) {
+		} else {
 
-            utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_OK, appGUI);
-            gtk_text_buffer_select_range (buffer, &match_start, &match_end);
-            gtk_text_buffer_create_mark (buffer, "last_pos", &match_end, FALSE);
+#endif  /* HAVE_LIBWEBKIT */
 
-            found_pos = gtk_text_buffer_create_mark (buffer, "found_pos", &match_end, FALSE);
-            gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (appGUI->nte->editor_textview), found_pos); 
-            gtk_text_buffer_delete_mark (buffer, found_pos);
+			flags = GTK_SOURCE_SEARCH_TEXT_ONLY;
 
-        } else {
-            utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_FAIL, appGUI);
-            if (gtk_text_buffer_get_mark (buffer, "last_pos") != NULL) {
-                gtk_text_buffer_delete_mark_by_name (buffer, "last_pos");
-            }
-        }
-    }
+			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->nte->find_case_checkbutton)) == FALSE) {
+				flags |= GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
+			}
+
+			buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+
+			if (forward == TRUE) {
+				result = gtk_source_iter_forward_search (iter, find_text, flags, &match_start, &match_end, NULL);
+			} else {
+				result = gtk_source_iter_backward_search (iter, find_text, flags, &match_start, &match_end, NULL);
+			}
+
+			if (result) {
+
+				utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_OK, appGUI);
+				gtk_text_buffer_select_range (buffer, &match_start, &match_end);
+				if (forward == TRUE) {
+					gtk_text_buffer_create_mark (buffer, "last_pos", &match_end, FALSE);
+				} else {
+					gtk_text_buffer_create_mark (buffer, "last_pos", &match_start, FALSE);
+				}
+
+				found_pos = gtk_text_buffer_create_mark (buffer, "found_pos", &match_end, FALSE);
+				gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (appGUI->nte->editor_textview), found_pos); 
+				gtk_text_buffer_delete_mark (buffer, found_pos);
+			
+				appGUI->nte->find_next_flag = TRUE;
+
+			} else {
+				utl_gui_change_bg_widget_state (appGUI->nte->find_entry, COLOR_BG_FAIL, appGUI);
+				if (gtk_text_buffer_get_mark (buffer, "last_pos") != NULL) {
+					gtk_text_buffer_delete_mark_by_name (buffer, "last_pos");
+				}
+				appGUI->nte->find_next_flag = FALSE;
+			}
+		}
+#ifdef HAVE_LIBWEBKIT
+	}
+#endif  /* HAVE_LIBWEBKIT */
 
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-find_entry_action (GUI *appGUI) {
+find_entry_action (gboolean forward, GUI *appGUI) {
 
+gchar *find_text;
+gboolean wkflag;
 GtkTextBuffer *buffer;
 GtkTextMark *last_pos;
 GtkTextIter iter;
-gchar *find_text;
 
-    find_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->find_entry)));
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+	find_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->find_entry)));
 
-    if (appGUI->nte->find_next_flag == TRUE) {
+	wkflag = FALSE;
+#ifdef HAVE_LIBWEBKIT
+	wkflag = TRUE;
+#endif  /* HAVE_LIBWEBKIT */
 
-        last_pos = gtk_text_buffer_get_mark (buffer, "last_pos");
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->nte->readonly_checkbutton)) && wkflag == TRUE) {
 
-        if (last_pos == NULL) {
-            gtk_text_buffer_get_start_iter (buffer, &iter);
-            find (find_text, &iter, appGUI);
-            g_free(find_text);
-            return;
-        }
+		find (find_text, NULL, forward, appGUI);
 
-        gtk_text_buffer_get_iter_at_mark (buffer, &iter, last_pos);
-        find (find_text, &iter, appGUI);
+	} else {
 
-    } else {
-        gtk_text_buffer_get_start_iter (buffer, &iter);
-        find (find_text, &iter, appGUI);
-    }
+		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
-    g_free(find_text);
+		if (appGUI->nte->find_next_flag == TRUE) {
+
+			last_pos = gtk_text_buffer_get_mark (buffer, "last_pos");
+
+			if (last_pos == NULL) {
+				appGUI->nte->find_next_flag = FALSE;
+				g_free(find_text);
+				return;
+			}
+
+			gtk_text_buffer_get_iter_at_mark (buffer, &iter, last_pos);
+			find (find_text, &iter, forward, appGUI);
+
+		} else {
+			if (forward == TRUE) {
+				gtk_text_buffer_get_start_iter (buffer, &iter);
+			} else {
+				gtk_text_buffer_get_end_iter (buffer, &iter);
+			}
+			find (find_text, &iter, forward, appGUI);
+		}
+
+		g_free(find_text);
+	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -745,11 +809,8 @@ find_entry_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
             appGUI->nte->find_next_flag = FALSE;
             return TRUE;
     } else if (event->keyval == GDK_Return) {
-            find_entry_action (appGUI);
-            appGUI->nte->find_next_flag = TRUE;
+            find_entry_action (TRUE, appGUI);
             return TRUE;
-    } else {
-        appGUI->nte->find_next_flag = FALSE;
     }
     return FALSE;
 }
@@ -802,8 +863,8 @@ refresh_notes (GUI *appGUI) {
 
 GtkTreeIter iter;
 gint i;
-guint32 current_date;
-gint current_time;
+guint32 current_date, create_date;
+gint current_time, create_time;
 
 	i = 0;
 
@@ -811,10 +872,13 @@ gint current_time;
 
 		gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
 							N_COLUMN_LAST_CHANGES_DATE_JULIAN, &current_date, 
-							N_COLUMN_LAST_CHANGES_TIME, &current_time, -1);
+							N_COLUMN_LAST_CHANGES_TIME, &current_time,
+							N_COLUMN_CREATE_DATE_JULIAN, &create_date, 
+							N_COLUMN_CREATE_TIME, &create_time, -1);
 
 		gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
-						    N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time), -1);
+						    N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time),
+						    N_COLUMN_CREATE_DATE, get_date_time_str (create_date, create_time), -1);
 	}
 
 	update_notes_items (appGUI);
@@ -1165,6 +1229,30 @@ gchar tmpbuf[BUFFER_SIZE];
 
 /*------------------------------------------------------------------------------*/
 
+void
+update_readonly_view (GUI *appGUI) {
+
+gchar *output = g_strdup ("");
+gchar *text;
+GtkTextBuffer *buffer;
+
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+	text = utl_gui_text_buffer_get_text_with_tags (buffer);
+
+	output = utl_text_to_html_page (text, pango_font_description_get_family (appGUI->nte->fd_notes_font), 
+									NULL, NULL, NULL, NULL, NULL);
+	g_free(text);
+
+#ifdef HAVE_LIBWEBKIT
+	g_object_set (appGUI->nte->webkit_settings, "default-font-size", PANGO_PIXELS(pango_font_description_get_size (appGUI->nte->fd_notes_font)), NULL);
+	webkit_web_view_load_string (WEBKIT_WEB_VIEW (appGUI->nte->html_webkitview), output, "text/html", "UTF-8", "file://");
+#endif  /* HAVE_LIBWEBKIT */
+
+	g_free(output);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 readonly_toggle_cb (GtkToggleButton *togglebutton, gpointer data) {
 
@@ -1184,11 +1272,23 @@ readonly_toggle_cb (GtkToggleButton *togglebutton, gpointer data) {
 	gtk_widget_set_sensitive (appGUI->nte->font_picker, !s);
 
 	if (s == TRUE) {
+		update_readonly_view (appGUI);
+
 		gtk_label_set_text(GTK_LABEL(appGUI->nte->nrow_label), "-");
 		gtk_label_set_text(GTK_LABEL(appGUI->nte->ncol_label), "-");
+#ifdef HAVE_LIBWEBKIT
+		gtk_widget_hide(appGUI->nte->editor_viewport);
+		gtk_widget_show(appGUI->nte->ro_editor_viewport);
+#endif /* HAVE_LIBWEBKIT */
 	} else {
+#ifdef HAVE_LIBWEBKIT
+		gtk_widget_show(appGUI->nte->editor_viewport);
+		gtk_widget_hide(appGUI->nte->ro_editor_viewport);
+#endif /* HAVE_LIBWEBKIT */
 		editor_cursor_move_cb (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)),
 							   NULL, NULL, appGUI);
+	
+		gtk_widget_grab_focus (appGUI->nte->editor_textview);
 	}
 
 	appGUI->nte->note_read_only = s;
@@ -1242,6 +1342,7 @@ nte_clear_find_cb (GtkWidget *widget, gpointer user_data)
         gtk_entry_set_text(GTK_ENTRY(appGUI->nte->notes_find_entry), "");
 		notes_search_entry_changed_cb (NULL, NULL, appGUI);
 	}
+	gtk_widget_grab_focus (appGUI->nte->notes_find_entry);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1252,20 +1353,53 @@ nte_font_selected (GtkFontButton *widget, gpointer user_data) {
 	GUI *appGUI = (GUI *) user_data;
 
     pango_font_description_free(appGUI->nte->fd_notes_font);
-    appGUI->nte->fd_notes_font = pango_font_description_from_string(gtk_font_button_get_font_name (GTK_FONT_BUTTON(widget)));
+    appGUI->nte->fd_notes_font = pango_font_description_from_string(gtk_font_button_get_font_name (GTK_FONT_BUTTON(widget)));	
     gtk_widget_modify_font (GTK_WIDGET(appGUI->nte->editor_textview), appGUI->nte->fd_notes_font);
 
 }
 
 /*------------------------------------------------------------------------------*/
 
+void
+editor_find_backward_cb (GtkWidget *widget, gpointer user_data) {
+
+	GUI *appGUI = (GUI *)user_data;
+	find_entry_action (FALSE, appGUI);
+}
+
+void
+editor_find_forward_cb (GtkWidget *widget, gpointer user_data) {
+
+	GUI *appGUI = (GUI *)user_data;
+	find_entry_action (TRUE, appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+
+static void
+button_create_backup_cb (GtkWidget *widget, GUI *appGUI)
+{
+	backup_create (appGUI);
+}
+
+static void
+button_restore_backup_cb (GtkWidget *widget, GUI *appGUI)
+{
+	backup_restore (appGUI);
+}
+
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
+
+/*------------------------------------------------------------------------------*/
+
 void 
 gui_create_notes (GUI *appGUI) {
 
 GtkWidget           *vbox1;
 GtkWidget           *hbox1;
 GtkTextBuffer       *buffer;
-GtkWidget           *viewport;
 GError              *error = NULL;
 GtkActionGroup      *action_group_selector = NULL;
 GtkActionGroup      *action_group_editor = NULL;
@@ -1274,6 +1408,8 @@ GtkWidget           *hseparator;
 GtkWidget           *label;
 GtkWidget           *vseparator;
 GtkWidget           *close_button;
+GtkWidget           *find_backward_button;
+GtkWidget           *find_forward_button;
 GtkWidget           *table;
 gint i, n;
 
@@ -1286,16 +1422,28 @@ gchar tmpbuf[BUFFER_SIZE];
 "    <separator/>\n"
 "    <toolitem name=\"delete\" action=\"delete\" />\n"
 "    <separator expand=\"true\" />\n"
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+"    <separator/>\n"
+"    <toolitem name=\"backup_data\" action=\"backup_data\" />\n"
+"    <toolitem name=\"restore_data\" action=\"restore_data\" />\n"
+"    <separator/>\n"
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
 "    <toolitem name=\"preferences\" action=\"preferences\" />\n"
 "    <toolitem name=\"about\" action=\"about\" />\n"
+"    <toolitem name=\"quit\" action=\"quit\" />\n"
 "  </toolbar>\n";
 
 GtkActionEntry entries_selector[] = {
 	{ "new", OSMO_STOCK_NOTES_ADD, _("New note"), NULL, _("Add note"), G_CALLBACK(notes_add_item_cb)},
 	{ "edit", OSMO_STOCK_NOTES_EDIT, _("Edit note"), NULL, _("Edit note"), G_CALLBACK(notes_edit_item_cb)},
 	{ "delete", OSMO_STOCK_NOTES_REMOVE, _("Delete note"), NULL, _("Remove note"), G_CALLBACK(notes_delete_item_cb)},
+#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
+    { "backup_data", OSMO_STOCK_BACKUP, _("Backup data"), NULL, _("Backup data"), G_CALLBACK(button_create_backup_cb)},
+    { "restore_data", OSMO_STOCK_RESTORE, _("Restore data"), NULL, _("Restore data"), G_CALLBACK(button_restore_backup_cb)},
+#endif  /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
 	{ "preferences", OSMO_STOCK_PREFERENCES, _("Preferences"), NULL, _("Preferences"), G_CALLBACK (show_preferences_window_cb)},
 	{ "about", OSMO_STOCK_ABOUT, _("About"), NULL, _("About"), G_CALLBACK (show_about_window_cb)},
+	{ "quit", GTK_STOCK_QUIT, _("Quit"), NULL, _("Quit"), G_CALLBACK (gui_quit_osmo_cb)},
 };
 
 guint n_entries_selector = G_N_ELEMENTS (entries_selector);
@@ -1552,15 +1700,15 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 
     /*-------------------------------------------------------------------------------------*/
 
-    viewport = gtk_viewport_new (NULL, NULL);
-    gtk_widget_show (viewport);
-    gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport), GTK_SHADOW_IN);
-    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_selector), viewport, TRUE, TRUE, 0);
+    appGUI->nte->editor_viewport = gtk_viewport_new (NULL, NULL);
+    gtk_widget_show (appGUI->nte->editor_viewport);
+    gtk_viewport_set_shadow_type (GTK_VIEWPORT (appGUI->nte->editor_viewport), GTK_SHADOW_IN);
+    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_selector), appGUI->nte->editor_viewport, TRUE, TRUE, 0);
 
     appGUI->nte->scrolled_win = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_show (appGUI->nte->scrolled_win);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->nte->scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_container_add (GTK_CONTAINER (viewport), appGUI->nte->scrolled_win);
+    gtk_container_add (GTK_CONTAINER (appGUI->nte->editor_viewport), appGUI->nte->scrolled_win);
 
     appGUI->nte->notes_list_store = gtk_list_store_new(NOTES_NUM_COLUMNS,
                                                        GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING,
@@ -1765,23 +1913,23 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
     gtk_widget_show (hseparator);
     gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_editor), hseparator, FALSE, TRUE, 4);
 
-    viewport = gtk_viewport_new (NULL, NULL);
-    gtk_widget_show (viewport);
-    gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport), GTK_SHADOW_IN);
-    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_editor), viewport, TRUE, TRUE, 0);
+    appGUI->nte->editor_viewport = gtk_viewport_new (NULL, NULL);
+    gtk_widget_show (appGUI->nte->editor_viewport);
+    gtk_viewport_set_shadow_type (GTK_VIEWPORT (appGUI->nte->editor_viewport), GTK_SHADOW_IN);
+    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_editor), appGUI->nte->editor_viewport, TRUE, TRUE, 0);
   
     appGUI->nte->editor_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_show (appGUI->nte->editor_scrolledwindow);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->nte->editor_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_container_add (GTK_CONTAINER (viewport), appGUI->nte->editor_scrolledwindow);
+    gtk_container_add (GTK_CONTAINER (appGUI->nte->editor_viewport), appGUI->nte->editor_scrolledwindow);
 
     appGUI->nte->editor_textview = gtk_text_view_new ();
     gtk_widget_show (appGUI->nte->editor_textview);
     gtk_container_add (GTK_CONTAINER (appGUI->nte->editor_scrolledwindow), appGUI->nte->editor_textview);
     gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (appGUI->nte->editor_textview), GTK_WRAP_WORD_CHAR);
     gtk_text_view_set_pixels_above_lines(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
-    gtk_text_view_set_left_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
-    gtk_text_view_set_right_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 4);
+    gtk_text_view_set_left_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 8);
+    gtk_text_view_set_right_margin(GTK_TEXT_VIEW(appGUI->nte->editor_textview), 8);
 
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
     appGUI->nte->buffer_check_modify_enable = FALSE;
@@ -1823,6 +1971,40 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
                       G_CALLBACK(notes_spell_check_cb), appGUI);
 #endif /* HAVE_GTKSPELL */
 
+	/* read-only view */
+#ifdef HAVE_LIBWEBKIT
+
+	appGUI->nte->ro_editor_viewport = gtk_viewport_new (NULL, NULL);
+    gtk_widget_show (appGUI->nte->ro_editor_viewport);
+    gtk_viewport_set_shadow_type (GTK_VIEWPORT (appGUI->nte->ro_editor_viewport), GTK_SHADOW_IN);
+    gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_editor), appGUI->nte->ro_editor_viewport, TRUE, TRUE, 0);
+  
+    appGUI->nte->ro_editor_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+    gtk_widget_show (appGUI->nte->ro_editor_scrolledwindow);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->nte->ro_editor_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_container_add (GTK_CONTAINER (appGUI->nte->ro_editor_viewport), appGUI->nte->ro_editor_scrolledwindow);
+
+	appGUI->nte->webkit_settings = webkit_web_settings_new ();
+
+	g_object_set (appGUI->nte->webkit_settings, "enable-scripts", FALSE, NULL);
+    g_object_set (appGUI->nte->webkit_settings, "enable-plugins", FALSE, NULL);
+
+	appGUI->nte->html_webkitview = WEBKIT_WEB_VIEW (webkit_web_view_new ());
+	webkit_web_view_set_settings (appGUI->nte->html_webkitview, appGUI->nte->webkit_settings);
+	webkit_web_view_set_editable (appGUI->nte->html_webkitview, FALSE);
+
+	g_signal_connect (appGUI->nte->html_webkitview, "populate-popup", 
+					  G_CALLBACK (utl_webkit_on_menu), appGUI);
+	g_signal_connect (appGUI->nte->html_webkitview, "navigation-policy-decision-requested",
+					  G_CALLBACK (utl_webkit_link_clicked), appGUI);
+
+	gtk_widget_show (GTK_WIDGET(appGUI->nte->html_webkitview));
+    gtk_container_add (GTK_CONTAINER (appGUI->nte->ro_editor_scrolledwindow), 
+					   GTK_WIDGET(appGUI->nte->html_webkitview));
+
+	gtk_widget_hide(appGUI->nte->ro_editor_viewport);
+#endif  /* HAVE_LIBWEBKIT */
+
 	hbox1 = gtk_hbox_new (FALSE, 1);
     gtk_widget_show (hbox1);
     gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_editor), hbox1, FALSE, FALSE, 2);
@@ -1883,6 +2065,22 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
     g_signal_connect (G_OBJECT (appGUI->nte->find_entry), "key_press_event",
                       G_CALLBACK (find_entry_key_press_cb), appGUI);
 
+    find_backward_button = utl_gui_stock_button (GTK_STOCK_GO_BACK, FALSE);
+    GTK_WIDGET_UNSET_FLAGS(find_backward_button, GTK_CAN_FOCUS);
+    gtk_button_set_relief (GTK_BUTTON(find_backward_button), GTK_RELIEF_NONE);
+    gtk_widget_show (find_backward_button);
+    gtk_box_pack_start (GTK_BOX (appGUI->nte->find_hbox), find_backward_button, FALSE, FALSE, 1);
+    g_signal_connect (G_OBJECT (find_backward_button), "clicked",
+                      G_CALLBACK (editor_find_backward_cb), appGUI);
+
+	find_forward_button = utl_gui_stock_button (GTK_STOCK_GO_FORWARD, FALSE);
+    gtk_button_set_relief (GTK_BUTTON(find_forward_button), GTK_RELIEF_NONE);
+    GTK_WIDGET_UNSET_FLAGS(find_forward_button, GTK_CAN_FOCUS);
+    gtk_widget_show (find_forward_button);
+    gtk_box_pack_start (GTK_BOX (appGUI->nte->find_hbox), find_forward_button, FALSE, FALSE, 1);
+    g_signal_connect (G_OBJECT (find_forward_button), "clicked",
+                      G_CALLBACK (editor_find_forward_cb), appGUI);
+
     appGUI->nte->find_case_checkbutton = gtk_check_button_new_with_mnemonic (_("case sensitive"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->nte->find_case_checkbutton, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->nte->find_case_checkbutton);
