@@ -2,7 +2,7 @@
 /*
  * Osmo - a handy personal organizer
  *
- * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
+ * Copyright (C) 2007-2014 Tomasz Maka <pasp@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 
 #include "notes_items.h"
 #include "i18n.h"
-#include "options_gui.h"
 #include "options_prefs.h"
 #include "notes.h"
+#include "notes_preferences_gui.h"
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
@@ -32,7 +32,6 @@
 #include "utils_gui.h"
 #include "utils_date.h"
 #include "stock_icons.h"
-#include "options_gui_notes.h"
 
 #ifdef NOTES_ENABLED
 
@@ -187,188 +186,163 @@ notes_add_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer
 /*------------------------------------------------------------------------------*/
 
 void
-notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI) {
+notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
+{
+	GtkWidget *vbox1;
+	GtkWidget *hseparator;
+	GtkWidget *hbuttonbox;
+	GtkWidget *cancel_button;
+	GtkWidget *label;
+	GtkWidget *frame;
+	GtkWidget *table;
+	GtkWidget *alignment;
 
-GtkWidget *vbox1;
-GtkWidget *hseparator;
-GtkWidget *hbuttonbox;
-GtkWidget *cancel_button;
-GtkWidget *label;
-GtkWidget *frame;
-GtkWidget *table;
-GtkWidget *alignment;
+	GtkTreePath *sort_path, *filter_path, *path;
+	GtkTreeIter iter;
+	gchar *c_category, *category, *name;
+	gchar tmpbuf[BUFFER_SIZE];
+	gboolean remember_cursor;
+	gint i, n;
 
-gchar tmpbuf[BUFFER_SIZE];
-gint i, n;
-gboolean remember_cursor;
-gchar *c_category, *category, *name;
-GtkTreeIter iter;
-GtkTreePath *sort_path, *filter_path, *path;
+	gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
+	if (sort_path == NULL) return;
 
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
+	filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (appGUI->nte->notes_sort), sort_path);
+	gtk_tree_path_free (sort_path);
+	if (filter_path == NULL) return;
 
-    if (sort_path != NULL) {
+	path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (appGUI->nte->notes_filter), filter_path);
+	gtk_tree_path_free (filter_path);
+	if (path == NULL) return;
 
-        filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
-        gtk_tree_path_free (sort_path);
+	appGUI->nte->edit_entry_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_container_set_border_width (GTK_CONTAINER (appGUI->nte->edit_entry_window), 4);
+	gtk_window_set_title (GTK_WINDOW (appGUI->nte->edit_entry_window), _("Edit entry"));
+	gtk_window_set_default_size (GTK_WINDOW (appGUI->nte->edit_entry_window), 400, -1);
+	if (config.fullscreen == FALSE) {
+		gtk_window_set_transient_for (GTK_WINDOW (appGUI->nte->edit_entry_window), GTK_WINDOW (appGUI->main_window));
+	}
+	gtk_window_set_position (GTK_WINDOW (appGUI->nte->edit_entry_window), GTK_WIN_POS_CENTER_ON_PARENT);
+	gtk_window_set_modal (GTK_WINDOW (appGUI->nte->edit_entry_window), TRUE);
+	g_signal_connect (G_OBJECT (appGUI->nte->edit_entry_window), "delete_event",
+	                  G_CALLBACK (notes_edit_close_cb), appGUI);
+	g_signal_connect (G_OBJECT (appGUI->nte->edit_entry_window), "key_press_event",
+	                  G_CALLBACK (notes_edit_key_press_cb), appGUI);
 
-        if (filter_path == NULL) return;
+	vbox1 = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (appGUI->nte->edit_entry_window), vbox1);
 
-        path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
-        gtk_tree_path_free (filter_path);
+	table = gtk_table_new (1, 2, FALSE);
+	gtk_box_pack_start (GTK_BOX (vbox1), table, FALSE, TRUE, 0);
 
-        appGUI->nte->edit_entry_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-        gtk_container_set_border_width (GTK_CONTAINER (appGUI->nte->edit_entry_window), 4);
-        gtk_window_set_title (GTK_WINDOW (appGUI->nte->edit_entry_window), _("Edit entry"));
-        gtk_window_set_default_size (GTK_WINDOW(appGUI->nte->edit_entry_window), 400, -1);
-        gtk_window_set_transient_for(GTK_WINDOW(appGUI->nte->edit_entry_window), GTK_WINDOW(appGUI->main_window));
-        gtk_window_set_position(GTK_WINDOW(appGUI->nte->edit_entry_window), GTK_WIN_POS_CENTER_ON_PARENT);
-        gtk_window_set_modal(GTK_WINDOW(appGUI->nte->edit_entry_window), TRUE);
-        g_signal_connect (G_OBJECT (appGUI->nte->edit_entry_window), "delete_event",
-                          G_CALLBACK(notes_edit_close_cb), appGUI);
-        g_signal_connect (G_OBJECT (appGUI->nte->edit_entry_window), "key_press_event",
-                          G_CALLBACK (notes_edit_key_press_cb), appGUI);
+	frame = gtk_frame_new (NULL);
+	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
+	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-        vbox1 = gtk_vbox_new (FALSE, 0);
-        gtk_widget_show (vbox1);
-        gtk_container_add (GTK_CONTAINER (appGUI->nte->edit_entry_window), vbox1);
+	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
-        table = gtk_table_new (1, 2, FALSE);
-        gtk_widget_show (table);
-        gtk_box_pack_start (GTK_BOX (vbox1), table, FALSE, TRUE, 0);
+	appGUI->nte->note_name_entry = gtk_entry_new ();
+	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->note_name_entry);
+	gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->note_name_entry), 8226);
+	g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "key_release_event",
+	                  G_CALLBACK (notes_add_entry_key_release_cb), appGUI);
 
-        frame = gtk_frame_new (NULL);
-        gtk_widget_show (frame);
-        gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1,
-                          (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                          (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
-        gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+	gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
+	filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (appGUI->nte->notes_sort), sort_path);
+	gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->nte->notes_filter), &iter, filter_path);
+	gtk_tree_path_free (filter_path);
+	gtk_tree_model_get (GTK_TREE_MODEL (appGUI->nte->notes_filter), &iter,
+	                    N_COLUMN_NAME, &name,
+	                    N_COLUMN_CATEGORY, &c_category,
+	                    N_COLUMN_REMEMBER_EDITOR_LINE, &remember_cursor,
+	                    -1);
 
-        alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-        gtk_widget_show (alignment);
-        gtk_container_add (GTK_CONTAINER (frame), alignment);
-        gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-        gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
+	gtk_entry_set_text (GTK_ENTRY (appGUI->nte->note_name_entry), name);
+	g_free (name);
 
-        appGUI->nte->note_name_entry = gtk_entry_new ();
-        gtk_widget_show (appGUI->nte->note_name_entry);
-        gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->note_name_entry);
-        gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->note_name_entry), 8226);
-        g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "key_release_event",
-                          G_CALLBACK (notes_add_entry_key_release_cb), appGUI);
- 
-        gtk_tree_model_get_iter (model, &iter, path);
-        gtk_tree_model_get (model, &iter, N_COLUMN_NAME, &name, -1);
-        gtk_entry_set_text (GTK_ENTRY(appGUI->nte->note_name_entry), name);
-        g_free (name);
+	sprintf (tmpbuf, "<b>%s:</b>", _("Note name"));
+	label = gtk_label_new (tmpbuf);
+	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-        sprintf (tmpbuf, "<b>%s:</b>", _("Note name"));
-        label = gtk_label_new (tmpbuf);
-        gtk_widget_show (label);
-        gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	frame = gtk_frame_new (NULL);
+	gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
+	                  (GtkAttachOptions) (GTK_FILL),
+	                  (GtkAttachOptions) (GTK_FILL), 0, 0);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-        frame = gtk_frame_new (NULL);
-        gtk_widget_show (frame);
-        gtk_table_attach (GTK_TABLE (table), frame, 1, 2, 0, 1,
-                          (GtkAttachOptions) (GTK_FILL),
-                          (GtkAttachOptions) (GTK_FILL), 0, 0);
-        gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
-        alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-        gtk_widget_show (alignment);
-        gtk_container_add (GTK_CONTAINER (frame), alignment);
-        gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-        gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
+	appGUI->nte->category_combobox = gtk_combo_box_new_text ();
+	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->category_combobox);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), _("None"));
 
-        appGUI->nte->category_combobox = gtk_combo_box_new_text ();
-        gtk_widget_show (appGUI->nte->category_combobox);
-        gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->category_combobox);
-        gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), _("None"));
+	i = n = 0;
 
-        gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
-        filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
-        gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter, filter_path);
-        gtk_tree_path_free (filter_path);
-        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_filter), &iter, 
-							N_COLUMN_CATEGORY, &c_category, N_COLUMN_REMEMBER_EDITOR_LINE, &remember_cursor, -1);
+	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->notes_category_store), &iter, NULL, i++)) {
+		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->notes_category_store), &iter, 0, &category, -1);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), category);
+		if (!strcmp (category, c_category)) n = i;
+		g_free (category);
+	}
 
-        i = n = 0;
+	g_free (c_category);
 
-        while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
-            gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
-            gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), category);
-            if (!strcmp(category, c_category)) n = i;
-            g_free(category);
-        }
+	gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->nte->category_combobox), n);
 
-        g_free(c_category);
+	sprintf (tmpbuf, "<b>%s:</b>", _("Category"));
+	label = gtk_label_new (tmpbuf);
+	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-        gtk_combo_box_set_active (GTK_COMBO_BOX(appGUI->nte->category_combobox), n);
+	frame = gtk_frame_new (NULL);
+	gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
-        sprintf (tmpbuf, "<b>%s:</b>", _("Category"));
-        label = gtk_label_new (tmpbuf);
-        gtk_widget_show (label);
-        gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
-		frame = gtk_frame_new (NULL);
-		gtk_widget_show (frame);
-		gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
-		gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+	appGUI->nte->remember_cursor_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember cursor position"));
+	GTK_WIDGET_UNSET_FLAGS (appGUI->nte->remember_cursor_checkbutton, GTK_CAN_FOCUS);
+	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->remember_cursor_checkbutton);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->nte->remember_cursor_checkbutton), remember_cursor);
 
-		alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-		gtk_widget_show (alignment);
-		gtk_container_add (GTK_CONTAINER (frame), alignment);
-		gtk_container_set_border_width (GTK_CONTAINER (alignment), 4);
-		gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
+	sprintf (tmpbuf, "<b>%s:</b>", _("Options"));
+	label = gtk_label_new (tmpbuf);
+	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-		appGUI->nte->remember_cursor_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember cursor position"));
-		GTK_WIDGET_UNSET_FLAGS(appGUI->nte->remember_cursor_checkbutton, GTK_CAN_FOCUS);
-		gtk_widget_show (appGUI->nte->remember_cursor_checkbutton);
-		gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->remember_cursor_checkbutton);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->nte->remember_cursor_checkbutton), remember_cursor);
+	hseparator = gtk_hseparator_new ();
+	gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
 
-		sprintf (tmpbuf, "<b>%s:</b>", _("Options"));
-		label = gtk_label_new (tmpbuf);
-		gtk_widget_show (label);
-		gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	hbuttonbox = gtk_hbutton_box_new ();
+	gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, FALSE, 0);
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
+	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-        hseparator = gtk_hseparator_new ();
-        gtk_widget_show (hseparator);
-        gtk_box_pack_start (GTK_BOX (vbox1), hseparator, FALSE, TRUE, 4);
+	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	GTK_WIDGET_UNSET_FLAGS (cancel_button, GTK_CAN_FOCUS);
+	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
+	g_signal_connect (G_OBJECT (cancel_button), "clicked",
+	                  G_CALLBACK (button_notes_edit_close_cb), appGUI);
 
-        hbuttonbox = gtk_hbutton_box_new ();
-        gtk_widget_show (hbuttonbox);
-        gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox, FALSE, FALSE, 0);
-        gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
-        gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
+	appGUI->nte->add_entry_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+	GTK_WIDGET_UNSET_FLAGS (appGUI->nte->add_entry_ok_button, GTK_CAN_FOCUS);
+	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->nte->add_entry_ok_button);
+	g_signal_connect (G_OBJECT (appGUI->nte->add_entry_ok_button), "clicked",
+	                  G_CALLBACK (notes_edit_action_cb), appGUI);
 
-        if (config.default_stock_icons) {
-            cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-        } else {
-            cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-        }
-        GTK_WIDGET_UNSET_FLAGS(cancel_button, GTK_CAN_FOCUS);
-        gtk_widget_show (cancel_button);
-        gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
-        g_signal_connect (G_OBJECT (cancel_button), "clicked",
-                            G_CALLBACK (button_notes_edit_close_cb), appGUI);
-        
-        if (config.default_stock_icons) {
-            appGUI->nte->add_entry_ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
-        } else {
-            appGUI->nte->add_entry_ok_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OK);
-        }
-        GTK_WIDGET_UNSET_FLAGS(appGUI->nte->add_entry_ok_button, GTK_CAN_FOCUS);
-        gtk_widget_show (appGUI->nte->add_entry_ok_button);
-        gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->nte->add_entry_ok_button);
-        g_signal_connect (G_OBJECT (appGUI->nte->add_entry_ok_button), "clicked",
-                            G_CALLBACK (notes_edit_action_cb), appGUI);
-
-        gtk_widget_show (appGUI->nte->edit_entry_window);
-    }
+	gtk_widget_show_all (appGUI->nte->edit_entry_window);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -474,7 +448,6 @@ gboolean flag, remember_cursor;
 gchar *pass = NULL, *spass = NULL;
 GRG_CTX context;
 GRG_KEY keyholder;
-gint ret;
 #endif /* HAVE_LIBGRINGOTTS */
 
     GUI *appGUI = (GUI *)data;
@@ -516,9 +489,9 @@ gint ret;
 		grg_ctx_set_comp_algo (context, get_comp_algorithm_value());
 		grg_ctx_set_comp_ratio (context, get_comp_ratio_value());
 
-		ret = grg_encrypt_file (context, keyholder, 
-								(unsigned char*) notes_get_full_filename(current_filename, appGUI), 
-								(guchar *)empty_str, -1);
+		grg_encrypt_file (context, keyholder,
+		                  (unsigned char*) notes_get_full_filename (current_filename, appGUI),
+		                  (guchar *) empty_str, -1);
 
 		grg_free (context, empty_str, -1);
 		grg_key_free (context, keyholder);
@@ -646,7 +619,9 @@ GtkTreeIter iter;
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->nte->add_entry_window), 4);
     gtk_window_set_title (GTK_WINDOW (appGUI->nte->add_entry_window), _("Add note"));
     gtk_window_set_default_size (GTK_WINDOW(appGUI->nte->add_entry_window), 450, -1);
-    gtk_window_set_transient_for(GTK_WINDOW(appGUI->nte->add_entry_window), GTK_WINDOW(appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+        gtk_window_set_transient_for(GTK_WINDOW(appGUI->nte->add_entry_window), GTK_WINDOW(appGUI->main_window));
+	}
     gtk_window_set_position(GTK_WINDOW(appGUI->nte->add_entry_window), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_modal(GTK_WINDOW(appGUI->nte->add_entry_window), TRUE);
     g_signal_connect (G_OBJECT (appGUI->nte->add_entry_window), "delete_event",
@@ -850,22 +825,14 @@ GtkTreeIter iter;
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-    if (config.default_stock_icons) {
-        cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-    } else {
-        cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-    }
+	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     GTK_WIDGET_UNSET_FLAGS(cancel_button, GTK_CAN_FOCUS);
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     g_signal_connect (G_OBJECT (cancel_button), "clicked",
                         G_CALLBACK (button_notes_add_close_cb), appGUI);
     
-    if (config.default_stock_icons) {
-        appGUI->nte->add_entry_ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
-    } else {
-        appGUI->nte->add_entry_ok_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OK);
-    }
+    appGUI->nte->add_entry_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->nte->add_entry_ok_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->nte->add_entry_ok_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->nte->add_entry_ok_button);
@@ -1059,7 +1026,9 @@ gchar *current_filename;
 			gtk_container_set_border_width (GTK_CONTAINER (appGUI->nte->enter_password_window), 4);
 			gtk_window_set_title (GTK_WINDOW (appGUI->nte->enter_password_window), _("Authorization"));
 			gtk_window_set_default_size (GTK_WINDOW(appGUI->nte->enter_password_window), 350, -1);
-			gtk_window_set_transient_for(GTK_WINDOW(appGUI->nte->enter_password_window), GTK_WINDOW(appGUI->main_window));
+			if (config.fullscreen == FALSE) {
+				gtk_window_set_transient_for(GTK_WINDOW(appGUI->nte->enter_password_window), GTK_WINDOW(appGUI->main_window));
+			}
 			gtk_window_set_position(GTK_WINDOW(appGUI->nte->enter_password_window), GTK_WIN_POS_CENTER_ON_PARENT);
 			gtk_window_set_modal(GTK_WINDOW(appGUI->nte->enter_password_window), TRUE);
 			g_signal_connect (G_OBJECT (appGUI->nte->enter_password_window), "delete_event",
@@ -1104,22 +1073,14 @@ gchar *current_filename;
 			gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 			gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-			if (config.default_stock_icons) {
-				cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-			} else {
-				cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-			}
+			cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
 			GTK_WIDGET_UNSET_FLAGS(cancel_button, GTK_CAN_FOCUS);
 			gtk_widget_show (cancel_button);
 			gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 			g_signal_connect (G_OBJECT (cancel_button), "clicked",
 								G_CALLBACK (button_enter_password_close_cb), appGUI);
 			
-			if (config.default_stock_icons) {
-				ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
-			} else {
-				ok_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OK);
-			}
+			ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
 			GTK_WIDGET_UNSET_FLAGS(ok_button, GTK_CAN_FOCUS);
 			gtk_widget_show (ok_button);
 			gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
@@ -1149,11 +1110,11 @@ xmlDocPtr doc;
 xmlChar *key;
 xmlNodePtr node, cnode, category_node, main_node;
 GtkTreeIter iter;
-gchar *name, *category;
+gchar *name, *category, *create_date_str, *fontname;
 gchar *notes_dir, *str, *dir, *fullpath;
 gint last_changes_time, create_time, editor_line;
 guint32 last_changes_date_julian, create_date_julian;
-gboolean remember_editor_line;
+gboolean remember_editor_line, editor_readonly;
 
     notes_dir = g_strdup(prefs_get_config_filename(NOTES_DIRNAME, appGUI));
     if (g_file_test (notes_dir, G_FILE_TEST_IS_DIR | G_FILE_TEST_EXISTS) == FALSE) {
@@ -1214,7 +1175,9 @@ gboolean remember_editor_line;
                         cnode = node->xmlChildrenNode;
 
 						remember_editor_line = FALSE;
+						editor_readonly = FALSE;
                         editor_line = 0;
+						fontname = NULL;
 
                         while (cnode != NULL) {
 
@@ -1226,6 +1189,8 @@ gboolean remember_editor_line;
 							utl_xml_get_int ("create_time", &create_time, cnode);
 							utl_xml_get_int ("remember_editor_line", &remember_editor_line, cnode);
 							utl_xml_get_int ("editor_line", &editor_line, cnode);
+							utl_xml_get_int ("read_only", &editor_readonly, cnode);
+							utl_xml_get_str ("fontname", &fontname, cnode);
 
                             if ((!xmlStrcmp(cnode->name, (const xmlChar *) "filename"))) {
                                 key = xmlNodeListGetString(doc, cnode->xmlChildrenNode, 1);
@@ -1243,18 +1208,29 @@ gboolean remember_editor_line;
 										}
 
 										gtk_list_store_append (appGUI->nte->notes_list_store, &iter);
+
+										create_date_str = g_strdup(get_date_time_str (create_date_julian, create_time));
+
+										if (fontname == NULL) {
+											fontname = g_strdup("Sans 12");
+										}
+
 										gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
 															N_COLUMN_NAME, name, 
 															N_COLUMN_CATEGORY, category, 
 															N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (last_changes_date_julian, last_changes_time),
 															N_COLUMN_LAST_CHANGES_DATE_JULIAN, last_changes_date_julian,
 															N_COLUMN_LAST_CHANGES_TIME, last_changes_time,
-															N_COLUMN_CREATE_DATE, get_date_time_str (create_date_julian, create_time),
+															N_COLUMN_CREATE_DATE, create_date_str,
 															N_COLUMN_CREATE_DATE_JULIAN, create_date_julian,
 															N_COLUMN_CREATE_TIME, create_time,
 															N_COLUMN_REMEMBER_EDITOR_LINE, remember_editor_line,
-															N_COLUMN_EDITOR_LINE, editor_line, -1);
-	
+															N_COLUMN_FONTNAME, fontname,
+															N_COLUMN_EDITOR_LINE, editor_line,
+															N_COLUMN_EDITOR_READONLY, editor_readonly, -1);
+
+										g_free (create_date_str);
+
 										if (dir[0] == '.') {
 											gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
 																N_COLUMN_FILENAME, (gchar *)key, -1);
@@ -1267,7 +1243,10 @@ gboolean remember_editor_line;
 										g_free (str);
 										g_free (dir);
 										g_free (name);
+										g_free (fontname);
 										g_free (category);
+
+										fontname = NULL;
 									}
                                     xmlFree (key);
                                 }
@@ -1307,10 +1286,10 @@ xmlDocPtr doc;
 xmlNodePtr main_node, node, note_node;
 xmlAttrPtr attr;
 GtkTreeIter iter;
-gchar *category, *name, *note_filename;
+gchar *category, *name, *note_filename, *note_fontname;
 gint last_changes_time, create_time, editor_line;
 guint32 last_changes_date_julian, create_date_julian;
-gboolean remember_editor_line;
+gboolean remember_editor_line, editor_readonly;
 xmlChar *escaped;
 
     if ((appGUI->save_status & WRT_NOTES) != 0) return;
@@ -1351,6 +1330,8 @@ xmlChar *escaped;
 		                    N_COLUMN_CREATE_TIME, &create_time,
 		                    N_COLUMN_REMEMBER_EDITOR_LINE, &remember_editor_line,
 		                    N_COLUMN_EDITOR_LINE, &editor_line,
+		                    N_COLUMN_EDITOR_READONLY, &editor_readonly,
+		                    N_COLUMN_FONTNAME, &note_fontname,
 		                    N_COLUMN_FILENAME, &note_filename, -1);
 
 		note_node = xmlNewChild (node, NULL, (const xmlChar *) "entry", (xmlChar *) NULL);
@@ -1365,12 +1346,14 @@ xmlChar *escaped;
 		utl_xml_put_int ("create_time", create_time, note_node);
 		utl_xml_put_int ("remember_editor_line", remember_editor_line, note_node);
 		utl_xml_put_int ("editor_line", editor_line, note_node);
+		utl_xml_put_int ("read_only", editor_readonly, note_node);
+		utl_xml_put_str ("fontname", note_fontname, note_node, doc);
 		utl_xml_put_str ("filename", note_filename, note_node, doc);
 		g_free (note_filename);
 	}
 
 	xmlSaveFormatFileEnc (prefs_get_config_filename (NOTES_ENTRIES_FILENAME, appGUI), doc, "utf-8", 1);
-	xmlFree (attr);
+	xmlFreeProp (attr);
 	xmlFreeDoc (doc);
 
 	appGUI->save_status &= ~WRT_NOTES;
