@@ -92,6 +92,7 @@ gint i;
     config.window_y = 0;
     config.window_size_x = 540;
     config.window_size_y = 690;
+    config.fullscreen = 0;
     config.enable_tooltips = TRUE;
     config.latest_tab = 0;      /* calendar */
     config.tabs_position = GTK_POS_TOP;
@@ -100,6 +101,7 @@ gint i;
     config.default_stock_icons = FALSE;
     config.disable_underline_links = FALSE;
     config.rules_hint = FALSE;
+    config.toolbar_exit_button = FALSE;
     config.date_format = DATE_YYYY_MM_DD;
     config.time_format = TIME_24;
     config.enable_systray = TRUE;
@@ -137,6 +139,7 @@ gint i;
     config.timeline_end = 15*60;
     config.timeline_step = 60;
     config.di_show_current_time = TRUE;
+    config.di_show_current_time_seconds = TRUE;
     config.di_show_day_number = TRUE;
     config.di_show_current_day_distance = TRUE;
     config.di_show_marked_days = TRUE;
@@ -225,6 +228,7 @@ gint i;
     config.find_mode = CONTACTS_FF_FIRST_NAME;
     config.show_after_search = TRUE;
     config.hide_group_column = FALSE;
+    config.maps_provider = 0;
     config.contacts_pane_pos = 275;
     config.photo_width = 80;
     config.cnt_visible_age_column = TRUE;
@@ -346,6 +350,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("window_y", &config.window_y, general_node);
 					utl_xml_get_int ("window_size_x", &config.window_size_x, general_node);
 					utl_xml_get_int ("window_size_y", &config.window_size_y, general_node);
+					utl_xml_get_int ("fullscreen", &config.fullscreen, general_node);
 					utl_xml_get_int ("enable_tooltips", &config.enable_tooltips, general_node);
 					utl_xml_get_int ("latest_tab", &config.latest_tab, general_node);
 					utl_xml_get_int ("tabs_position", &config.tabs_position, general_node);
@@ -354,6 +359,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("default_stock_icons", &config.default_stock_icons, general_node);
 					utl_xml_get_int ("disable_underline_links", &config.disable_underline_links, general_node);
 					utl_xml_get_int ("rules_hint", &config.rules_hint, general_node);
+					utl_xml_get_int ("toolbar_exit_button", &config.toolbar_exit_button, general_node);
 					utl_xml_get_int ("date_format", &config.date_format, general_node);
 					utl_xml_get_int ("time_format", &config.time_format, general_node);
 					utl_xml_get_int ("enable_systray", &config.enable_systray, general_node);
@@ -401,6 +407,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("timeline_end", &config.timeline_end, calendar_node);
 					utl_xml_get_int ("timeline_step", &config.timeline_step, calendar_node);
 					utl_xml_get_int ("di_show_current_time", &config.di_show_current_time, calendar_node);
+					utl_xml_get_int ("di_show_current_time_seconds", &config.di_show_current_time_seconds, calendar_node);
 					utl_xml_get_int ("di_show_day_number", &config.di_show_day_number, calendar_node);
 					utl_xml_get_int ("di_show_current_day_distance", &config.di_show_current_day_distance, calendar_node);
 					utl_xml_get_int ("di_show_marked_days", &config.di_show_marked_days, calendar_node);
@@ -509,6 +516,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("find_mode", &config.find_mode, contacts_node);
 					utl_xml_get_int ("show_after_search", &config.show_after_search, contacts_node);
 					utl_xml_get_int ("hide_group_column", &config.hide_group_column, contacts_node);
+					utl_xml_get_int ("maps_provider", &config.maps_provider, contacts_node);
 					utl_xml_get_int ("pane_pos", &config.contacts_pane_pos, contacts_node);
 					utl_xml_get_int ("photo_width", &config.photo_width, contacts_node);
 					utl_xml_get_int ("visible_age_column", &config.cnt_visible_age_column, contacts_node);
@@ -632,6 +640,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("window_y", config.window_y, general_node);
 	utl_xml_put_int ("window_size_x", config.window_size_x, general_node);
 	utl_xml_put_int ("window_size_y", config.window_size_y, general_node);
+	utl_xml_put_int ("fullscreen", config.fullscreen, general_node);
 	utl_xml_put_int ("enable_tooltips", config.enable_tooltips, general_node);
 	utl_xml_put_int ("latest_tab", config.latest_tab, general_node);
 	utl_xml_put_int ("tabs_position", config.tabs_position, general_node);
@@ -640,6 +649,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("default_stock_icons", config.default_stock_icons, general_node);
 	utl_xml_put_int ("disable_underline_links", config.disable_underline_links, general_node);
 	utl_xml_put_int ("rules_hint", config.rules_hint, general_node);
+	utl_xml_put_int ("toolbar_exit_button", config.toolbar_exit_button, general_node);
 	utl_xml_put_int ("date_format", config.date_format, general_node);
 	utl_xml_put_int ("time_format", config.time_format, general_node);
 	utl_xml_put_int ("enable_systray", config.enable_systray, general_node);
@@ -681,6 +691,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("timeline_end", config.timeline_end, calendar_node);
 	utl_xml_put_int ("timeline_step", config.timeline_step, calendar_node);
 	utl_xml_put_int ("di_show_current_time", config.di_show_current_time, calendar_node);
+	utl_xml_put_int ("di_show_current_time_seconds", config.di_show_current_time_seconds, calendar_node);
 	utl_xml_put_int ("di_show_day_number", config.di_show_day_number, calendar_node);
 	utl_xml_put_int ("di_show_current_day_distance", config.di_show_current_day_distance, calendar_node);
 	utl_xml_put_int ("di_show_marked_days", config.di_show_marked_days, calendar_node);
@@ -779,6 +790,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("find_mode", config.find_mode, contacts_node);
 	utl_xml_put_int ("show_after_search", config.show_after_search, contacts_node);
 	utl_xml_put_int ("hide_group_column", config.hide_group_column, contacts_node);
+	utl_xml_put_int ("maps_provider", config.maps_provider, contacts_node);
 	utl_xml_put_int ("pane_pos", config.contacts_pane_pos, contacts_node);
 	utl_xml_put_int ("photo_width", config.photo_width, contacts_node);
 	utl_xml_put_int ("visible_age_column", config.cnt_visible_age_column, contacts_node);
