@@ -44,6 +44,7 @@ struct osmo_prefs
     gint        window_y;
     gint        window_size_x;
     gint        window_size_y;
+    gint        fullscreen;
     gint        enable_tooltips;
     gint        latest_tab;
     gint        tabs_position;
@@ -52,6 +53,7 @@ struct osmo_prefs
     gint        default_stock_icons;
     gint        disable_underline_links;
     gint        rules_hint;
+    gint        toolbar_exit_button;
     gint        date_format;
     gint        time_format;
     gint        enable_systray;
@@ -89,6 +91,7 @@ struct osmo_prefs
     gint        timeline_end;
     gint        timeline_step;
     gint        di_show_current_time;
+    gint        di_show_current_time_seconds;
     gint        di_show_day_number;
     gint        di_show_current_day_distance;
     gint        di_show_marked_days;
@@ -177,6 +180,7 @@ struct osmo_prefs
     gint        find_mode;
     gint        show_after_search;
     gint        hide_group_column;
+    gint        maps_provider;
     gint        contacts_pane_pos;
     gint        photo_width;
     gint        cnt_visible_age_column;
