@@ -31,6 +31,16 @@
 #include "tasks.h"
 #include "tasks_preferences_gui.h"
 #include "utils_gui.h"
+#include "calendar.h"
+
+/* ========================================================================== */
+
+static void 
+show_restart_info(GUI *appGUI)
+{
+	utl_gui_create_dialog (GTK_MESSAGE_INFO, _("Osmo has to be restarted to take effect."),
+	                       GTK_WINDOW (appGUI->opt->window));
+}
 
 /* ========================================================================== */
 
@@ -42,13 +52,20 @@ checkbutton_clicked_cb (GtkToggleButton *togglebutton, gint *option)
 
 /* ========================================================================== */
 
+static void
+checkbutton_clicked_stock_icons_cb (GtkToggleButton *togglebutton, GUI *appGUI)
+{
+    config.default_stock_icons = gtk_toggle_button_get_active (togglebutton);
+	show_restart_info (appGUI);
+}
+
+/* ========================================================================== */
+
 static void
 layout_changed_cb (GtkComboBox *widget, GUI *appGUI)
 {
 	config.gui_layout = gtk_combo_box_get_active (widget);
-
-	utl_gui_create_dialog (GTK_MESSAGE_INFO, _("Osmo has to be restarted to take effect."),
-	                       GTK_WINDOW (appGUI->opt->window));
+	show_restart_info (appGUI);
 }
 
 /* ========================================================================== */
@@ -119,14 +136,53 @@ enable_rules_hint_changed_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 
 /* ========================================================================== */
 
+static void
+toolbar_exit_button_changed_cb (GtkToggleButton *togglebutton, GUI *appGUI)
+{
+	config.toolbar_exit_button = gtk_toggle_button_get_active (togglebutton);
+
+	if (config.toolbar_exit_button == TRUE) {
+		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->cal->calendar_uim_widget, "/toolbar/quit"));
+	} else {
+		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->cal->calendar_uim_widget, "/toolbar/quit"));
+	}
+
+#ifdef CONTACTS_ENABLED
+	if (config.toolbar_exit_button == TRUE) {
+		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/quit"));
+	} else {
+		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/quit"));
+	}
+#endif /* CONTACTS_ENABLED */
+
+#ifdef NOTES_ENABLED
+	if (config.toolbar_exit_button == TRUE) {
+		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/quit"));
+	} else {
+		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/quit"));
+	}
+#endif /* NOTES_ENABLED */
+
+#ifdef TASKS_ENABLED
+	if (config.toolbar_exit_button == TRUE) {
+		gtk_widget_show (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/quit"));
+	} else {
+		gtk_widget_hide (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/quit"));
+	}
+#endif /* TASKS_ENABLED */
+
+}
+
+/* ========================================================================== */
+
 static void
 create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 {
 	GtkWidget *table, *label, *combobox, *checkbutton;
 
-	table = gtk_table_new (1, 4, FALSE);
+	table = gtk_table_new (3, 4, FALSE);
 	gtk_box_pack_start (GTK_BOX (appearance_vbox), table, FALSE, TRUE, 0);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 16);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 32);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 8);
 
 	label = utl_gui_create_label ("%s:", _("Layout"));
@@ -155,20 +211,29 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.tabs_position);
 	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (tabs_position_changed_cb), appGUI);
 
-	checkbutton = gtk_check_button_new_with_mnemonic (_("Use default stock icons (needs restart)"));
+	checkbutton = gtk_check_button_new_with_mnemonic (_("Use default stock icons"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.default_stock_icons);
-	gtk_box_pack_start (GTK_BOX (appearance_vbox), checkbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.default_stock_icons));
+	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 2, 1, 2,
+	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_stock_icons_cb), appGUI);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Disable underline in links"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.disable_underline_links);
-	gtk_box_pack_start (GTK_BOX (appearance_vbox), checkbutton, FALSE, FALSE, 0);
+	gtk_table_attach (GTK_TABLE (table), checkbutton, 0, 2, 2, 3,
+	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (disable_underline_in_links_changed_cb), appGUI);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Draw rows in alternating colors"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.rules_hint);
-	gtk_box_pack_start (GTK_BOX (appearance_vbox), checkbutton, FALSE, FALSE, 0);
+	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 4, 1, 2,
+	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (enable_rules_hint_changed_cb), appGUI);
+
+	checkbutton = gtk_check_button_new_with_mnemonic (_("Show exit button in toolbar"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.toolbar_exit_button);
+	gtk_table_attach (GTK_TABLE (table), checkbutton, 2, 4, 2, 3,
+	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (toolbar_exit_button_changed_cb), appGUI);
 }
 
 /* ========================================================================== */
@@ -203,15 +268,25 @@ hide_module_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->opt->hide_calendar_checkbutton), FALSE);
 	}
 
+	opt_hide_modules (cal, tsk, cnt, nte, TRUE, appGUI);
+}
+
+void
+opt_hide_modules (gboolean cal, gboolean tsk, gboolean cnt, gboolean nte, gboolean options, GUI *appGUI)
+{
+	if (cal && tsk && nte && cnt) {
+		cal = FALSE;
+	}
+
 	if (cal) {
 		config.hide_calendar = TRUE;
 		gtk_widget_hide (GTK_WIDGET (appGUI->cal->vbox));
-		gtk_widget_hide (appGUI->opt->calendar);
+		if (options) gtk_widget_hide (appGUI->opt->calendar);
 		gtk_widget_hide (appGUI->trayicon_menu_calendar_item);
 	} else {
 		config.hide_calendar = FALSE;
 		gtk_widget_show (GTK_WIDGET (appGUI->cal->vbox));
-		gtk_widget_show (appGUI->opt->calendar);
+		if (options) gtk_widget_show (appGUI->opt->calendar);
 		gtk_widget_show (appGUI->trayicon_menu_calendar_item);
 	}
 
@@ -219,12 +294,12 @@ hide_module_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 	if (tsk) {
 		config.hide_tasks = TRUE;
 		gtk_widget_hide(GTK_WIDGET (appGUI->tsk->vbox));
-		gtk_widget_hide (appGUI->opt->tasks);
+		if (options) gtk_widget_hide (appGUI->opt->tasks);
 		gtk_widget_hide (appGUI->trayicon_menu_tasks_item);
 	} else {
 		config.hide_tasks = FALSE;
 		gtk_widget_show (GTK_WIDGET (appGUI->tsk->vbox));
-		gtk_widget_show (appGUI->opt->tasks);
+		if (options) gtk_widget_show (appGUI->opt->tasks);
 		gtk_widget_show (appGUI->trayicon_menu_tasks_item);
 	}
 #endif /* TASKS_ENABLED */
@@ -233,12 +308,12 @@ hide_module_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 	if (cnt) {
 		config.hide_contacts = TRUE;
 		gtk_widget_hide (GTK_WIDGET (appGUI->cnt->vbox));
-		gtk_widget_hide (appGUI->opt->contacts);
+		if (options) gtk_widget_hide (appGUI->opt->contacts);
 		gtk_widget_hide (appGUI->trayicon_menu_contacts_item);
 	} else {
 		config.hide_contacts = FALSE;
 		gtk_widget_show (GTK_WIDGET (appGUI->cnt->vbox));
-		gtk_widget_show (appGUI->opt->contacts);
+		if (options) gtk_widget_show (appGUI->opt->contacts);
 		gtk_widget_show (appGUI->trayicon_menu_contacts_item);
 	}
 #endif /* CONTACTS_ENABLED */
@@ -247,12 +322,12 @@ hide_module_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 	if (nte) {
 		config.hide_notes = TRUE;
 		gtk_widget_hide (GTK_WIDGET (appGUI->nte->vbox));
-		gtk_widget_hide (appGUI->opt->notes);
+		if (options) gtk_widget_hide (appGUI->opt->notes);
 		gtk_widget_hide (appGUI->trayicon_menu_notes_item);
 	} else {
 		config.hide_notes = FALSE;
 		gtk_widget_show (GTK_WIDGET (appGUI->nte->vbox));
-		gtk_widget_show (appGUI->opt->notes);
+		if (options) gtk_widget_show (appGUI->opt->notes);
 		gtk_widget_show (appGUI->trayicon_menu_notes_item);
 	}
 #endif /* NOTES_ENABLED */
@@ -340,6 +415,10 @@ date_format_changed_cb (GtkComboBox *widget, GUI *appGUI)
 {
 	config.date_format = gtk_combo_box_get_active (widget);
 
+#ifdef NOTES_ENABLED
+	refresh_notes (appGUI);
+#endif  /* NOTES_NOTES */
+
 #ifdef TASKS_ENABLED
 	refresh_tasks (appGUI);
 #endif  /* TASKS_ENABLED */
@@ -351,6 +430,11 @@ static void
 time_format_changed_cb (GtkComboBox *widget, GUI *appGUI)
 {
 	config.time_format = gtk_combo_box_get_active (widget);
+	update_clock (appGUI);
+
+#ifdef NOTES_ENABLED
+	refresh_notes (appGUI);
+#endif  /* NOTES_NOTES */
 
 #ifdef TASKS_ENABLED
 	refresh_tasks (appGUI);
@@ -575,48 +659,6 @@ create_helpers_section (GtkWidget *helpers_vbox, GUI *appGUI)
 
 /* ========================================================================== */
 
-#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
-
-static void
-button_create_backup_cb (GtkWidget *widget, GUI *appGUI)
-{
-	backup_create (appGUI);
-}
-
-/* ========================================================================== */
-
-static void
-button_restore_backup_cb (GtkWidget *widget, GUI *appGUI)
-{
-	backup_restore (appGUI);
-}
-
-/* ========================================================================== */
-
-static void
-create_backup_section (GtkWidget *backup_vbox, GUI *appGUI)
-{
-	GtkWidget *hbuttonbox, *create_button, *restore_button;
-
-	hbuttonbox = gtk_hbutton_box_new ();
-	gtk_container_add (GTK_CONTAINER (backup_vbox), hbuttonbox);
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_START);
-	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
-
-	create_button = gtk_button_new_with_label (_("Create"));
-	gtk_container_add (GTK_CONTAINER (hbuttonbox), create_button);
-	g_signal_connect (create_button, "clicked", G_CALLBACK (button_create_backup_cb), appGUI);
-
-	restore_button = gtk_button_new_with_label (_("Restore"));
-	gtk_container_add (GTK_CONTAINER (hbuttonbox), restore_button);
-	g_signal_connect (restore_button, "clicked", G_CALLBACK (button_restore_backup_cb), appGUI);
-
-}
-
-#endif /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
-
-/* ========================================================================== */
-
 static void
 enable_systray_changed_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 {
@@ -703,11 +745,6 @@ create_general_page (GtkWidget *notebook, GUI *appGUI)
 	vbox = utl_gui_create_vbox_in_frame (vbox_top, _("Helpers"));
 	create_helpers_section (vbox, appGUI);
 
-#if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
-	vbox = utl_gui_create_vbox_in_frame (vbox_top, _("Backup"));
-	create_backup_section (vbox, appGUI);
-#endif /* BACKUP_SUPPORT && HAVE_LIBGRINGOTTS */
-
 	vbox = utl_gui_create_vbox_in_frame (vbox_top, _("System tray"));
 	create_system_tray_section (vbox, appGUI);
 
@@ -748,7 +785,7 @@ opt_create_preferences_window (GUI *appGUI)
 	GtkWidget *notebook;
 	GtkWidget *hbuttonbox, *close_button;
 
-	window = utl_gui_create_window (_("Preferences"), 650, 600, appGUI);
+	window = utl_gui_create_window (_("Preferences"), 700, 600, appGUI);
 	g_signal_connect (G_OBJECT (window), "key_press_event", G_CALLBACK (key_press), appGUI);
 
 	vbox_top = gtk_vbox_new (FALSE, VBOX_SPACING);
