@@ -61,7 +61,10 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_SYSTRAY_NOTE,            (gchar*) N_("Note"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_SYSTRAY_MENU_CALENDAR,   (gchar*) N_("Calendar"),                     0, 0, TRANSLATION_DOMAIN },
 
-    { (gchar*) OSMO_STOCK_ABOUT,                   (gchar*) N_("About"),                        0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_BACKUP,                  (gchar*) N_("Backup data"),                  0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_RESTORE,                 (gchar*) N_("Restore data"),                 0, 0, TRANSLATION_DOMAIN },
+
+	{ (gchar*) OSMO_STOCK_ABOUT,                   (gchar*) N_("About"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALENDAR,                (gchar*) N_("Calendar"),                     0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CLOSE,                   (gchar*) N_("Close"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALCULATOR,              (gchar*) N_("Calculator"),                   0, 0, TRANSLATION_DOMAIN },
@@ -102,6 +105,12 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_SYSTRAY_MENU_NOTES,      (gchar*) N_("Notes"),                        0, 0, TRANSLATION_DOMAIN },
 #endif /* NOTES_ENABLED */
 
+    { (gchar*) OSMO_STOCK_EDITOR_BOLD_S,           (gchar*) N_("Bold"),                         0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_HIGHLIGHT_S,      (gchar*) N_("Highlight"),                    0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_ITALIC_S,         (gchar*) N_("Italic"),                       0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_STRIKETHROUGH_S,  (gchar*) N_("Strikethrough"),                0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_EDITOR_UNDERLINE_S,      (gchar*) N_("Underline"),                    0, 0, TRANSLATION_DOMAIN },
+
     { (gchar*) OSMO_STOCK_FULLYEAR,                (gchar*) N_("Display full-year calendar"),   0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_HELP,                    (gchar*) N_("Help"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_INFO_HELP,               (gchar*) N_("Help"),                         0, 0, TRANSLATION_DOMAIN },
@@ -121,8 +130,10 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_TASKS_ADD,               (gchar*) N_("Add task"),                     0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS_EDIT,              (gchar*) N_("Edit task"),                    0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS_REMOVE,            (gchar*) N_("Remove task"),                  0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_TASKS_PREV_DAY,          (gchar*) N_("Change due date to previous day"), 0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_TASKS_NEXT_DAY,          (gchar*) N_("Change due date to next day"),  0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_TASKS_IMPORT,            (gchar*) N_("Import tasks"),                 0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_TASKS_EXPORT,            (gchar*) N_("Export tasks"),                 0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_TASKS_PREV_DATE,         (gchar*) N_("Change to previous date"),      0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_TASKS_NEXT_DATE,         (gchar*) N_("Change to next date"),          0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_TASKS,                   (gchar*) N_("Tasks"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_SYSTRAY_TASK,            (gchar*) N_("Task"),                         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_SYSTRAY_MENU_TASKS,      (gchar*) N_("Tasks"),                        0, 0, TRANSLATION_DOMAIN },
@@ -134,10 +145,10 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_PRINT,                   (gchar*) N_("Print"),                        0, 0, TRANSLATION_DOMAIN },
 #endif /* PRINTING_SUPPORT */
 
-	{ (gchar*) OSMO_STOCK_TYPE_NORMAL,              (gchar*) N_("Normal"),                      0, 0, TRANSLATION_DOMAIN },
-	{ (gchar*) OSMO_STOCK_TYPE_ENCRYPTED,           (gchar*) N_("Encrypted"),                   0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_TYPE_RECURRENT,           (gchar*) N_("Recurrent"),                   0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_TYPE_RECURRENT_INACTIVE,  (gchar*) N_("Inactive recurrent"),          0, 0, TRANSLATION_DOMAIN }
+    { (gchar*) OSMO_STOCK_TYPE_NORMAL,              (gchar*) N_("Normal"),                      0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_TYPE_ENCRYPTED,           (gchar*) N_("Encrypted"),                   0, 0, TRANSLATION_DOMAIN },
+    /*{ (gchar*) OSMO_STOCK_TYPE_RECURRENT_INACTIVE,  (gchar*) N_("Inactive recurrent"),          0, 0, TRANSLATION_DOMAIN },*/
+    { (gchar*) OSMO_STOCK_TYPE_RECURRENT,           (gchar*) N_("Recurrent"),                   0, 0, TRANSLATION_DOMAIN }
 };
 
 const guint8* osmo_stock_item_data[] = {
@@ -167,7 +178,10 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_systray_note,
     (const guint8*) osmo_stock_systray_menu_calendar,
 
-    (const guint8*) osmo_stock_about,
+    (const guint8*) osmo_stock_backup,
+    (const guint8*) osmo_stock_restore,
+
+	(const guint8*) osmo_stock_about,
     (const guint8*) osmo_stock_calendar,
     (const guint8*) osmo_stock_close,
     (const guint8*) osmo_stock_calculator,
@@ -207,6 +221,12 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_notes,
     (const guint8*) osmo_stock_systray_menu_notes,
 #endif  /* NOTES_ENABLED */
+
+    (const guint8*) osmo_stock_editor_bold_s,
+    (const guint8*) osmo_stock_editor_highlight_s,
+    (const guint8*) osmo_stock_editor_italic_s,
+    (const guint8*) osmo_stock_editor_strikethrough_s,
+    (const guint8*) osmo_stock_editor_underline_s,
  
     (const guint8*) osmo_stock_fullyear,
     (const guint8*) osmo_stock_help,
@@ -227,8 +247,10 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_tasks_add,
     (const guint8*) osmo_stock_tasks_edit,
     (const guint8*) osmo_stock_tasks_remove,
-    (const guint8*) osmo_stock_tasks_prev_day,
-    (const guint8*) osmo_stock_tasks_next_day,
+    (const guint8*) osmo_stock_tasks_import,
+    (const guint8*) osmo_stock_tasks_export,
+    (const guint8*) osmo_stock_tasks_prev_date,
+    (const guint8*) osmo_stock_tasks_next_date,
     (const guint8*) osmo_stock_tasks,
     (const guint8*) osmo_stock_systray_task,
     (const guint8*) osmo_stock_systray_menu_tasks,
@@ -239,10 +261,10 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_print,
 #endif /* PRINTING_SUPPORT */
 
-	(const guint8*) osmo_stock_type_normal,
-	(const guint8*) osmo_stock_type_encrypted,
-    (const guint8*) osmo_stock_type_recurrent,
-    (const guint8*) osmo_stock_type_recurrent_inactive
+    (const guint8*) osmo_stock_type_normal,
+    (const guint8*) osmo_stock_type_encrypted,
+    /*(const guint8*) osmo_stock_type_recurrent_inactive,*/
+    (const guint8*) osmo_stock_type_recurrent
 };
 
     gtk_stock_add (osmo_stock_items, G_N_ELEMENTS (osmo_stock_items));
