@@ -1,8 +1,8 @@
-
 /*
  * Osmo - a handy personal organizer
  *
- * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
+ * Copyright (C) 2007-2014 Tomasz Maka <pasp@users.sourceforge.net>
+ *           (C) 2007-2014 Piotr Mąka <silloz@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,7 +77,8 @@ gint    task_calculate_new_date                 (TASK_ITEM *item, GUI *appGUI, g
 void    tasks_repeat_done                       (GtkTreeIter *iter, TASK_ITEM *item, GUI *appGUI);
 void    show_tasks_desc_panel                   (gboolean enable, GUI *appGUI);
 void    tasks_select_first_position_in_list     (GUI *appGUI);
-void    apply_task_attributes                   (GUI *appGUI);
+//void    apply_task_attributes                   (GUI *appGUI);
+void    set_categories                          (GUI *appGUI);
 void    refresh_tasks                           (GUI *appGUI);
 void    store_task_columns_info                 (GUI *appGUI);
 void    set_tasks_columns_width                 (GUI *appGUI);
