@@ -24,12 +24,11 @@
 #include "calendar_widget.h"
 #include "check_events.h"
 #include "i18n.h"
-#include "options_gui.h"
-#include "options_gui_tasks.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 #include "tasks.h"
 #include "tasks_items.h"
+#include "tasks_preferences_gui.h"
 #include "tasks_utils.h"
 #include "utils.h"
 #include "utils_gui.h"
@@ -187,7 +186,7 @@ gchar tmpbuf[BUFFER_SIZE];
     update_tasks_number (appGUI);
     tasks_select_first_position_in_list (appGUI);
     g_signal_emit_by_name (G_OBJECT(appGUI->cal->calendar), "day-selected");
-    apply_task_attributes (appGUI);
+	refresh_tasks (appGUI);
 
     tsk_item_free (item);
     cal_refresh_marks (appGUI);
@@ -379,7 +378,9 @@ TIME *tm;
     appGUI->tsk->td_calendar_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position (GTK_WINDOW (appGUI->tsk->td_calendar_window), GTK_WIN_POS_MOUSE);
     gtk_window_set_modal (GTK_WINDOW (appGUI->tsk->td_calendar_window), TRUE);
-    gtk_window_set_transient_for (GTK_WINDOW (appGUI->tsk->td_calendar_window), GTK_WINDOW (appGUI->tsk->tasks_add_window));
+	if (config.fullscreen == FALSE) {
+        gtk_window_set_transient_for (GTK_WINDOW (appGUI->tsk->td_calendar_window), GTK_WINDOW (appGUI->tsk->tasks_add_window));
+	}
     gtk_window_set_decorated (GTK_WINDOW (appGUI->tsk->td_calendar_window), FALSE);
     g_signal_connect (G_OBJECT (appGUI->tsk->td_calendar_window), "key_press_event",
                       G_CALLBACK (sd_key_press_cb), appGUI);
@@ -401,6 +402,8 @@ TIME *tm;
     gui_calendar_set_color (GUI_CALENDAR (appGUI->tsk->td_calendar), config.selection_color, config.selector_alpha, SELECTOR_COLOR);
     gui_calendar_set_marker (GUI_CALENDAR (appGUI->tsk->td_calendar), config.today_marker_type, TODAY_MARKER);
     gui_calendar_set_color (GUI_CALENDAR (appGUI->tsk->td_calendar), config.mark_current_day_color, config.mark_current_day_alpha, TODAY_MARKER_COLOR);
+    gui_calendar_set_color (GUI_CALENDAR (appGUI->tsk->td_calendar), config.header_color, 0,  HEADER_COLOR);
+    gui_calendar_set_color (GUI_CALENDAR (appGUI->tsk->td_calendar), config.weekend_color, 0, WEEKEND_COLOR);
     gtk_widget_show (appGUI->tsk->td_calendar);
     g_signal_connect (GTK_OBJECT (appGUI->tsk->td_calendar), "day_selected_double_click",
                       G_CALLBACK (day_selected_cb), appGUI);
@@ -552,24 +555,40 @@ tasks_add_edit_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer dat
 
 GUI *appGUI = (GUI *)data;
 
-    switch(event->keyval) {
+	switch(event->keyval) {
 
         case GDK_Escape:
             tasks_add_edit_window_close_cb (appGUI->tsk->tasks_add_window, NULL, appGUI);
             return TRUE;
+        case GDK_Return:
+			if (gtk_widget_is_focus(appGUI->tsk->desc_textview) == FALSE) {
+	            if (appGUI->tsk->tasks_accept_state == TRUE ) {
+					g_signal_emit_by_name(G_OBJECT(appGUI->tsk->tasks_ok_button), "clicked");
+					return TRUE;
+				} 
+			} else if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Return */
+				g_signal_emit_by_name(G_OBJECT(appGUI->tsk->tasks_ok_button), "clicked");
+				return TRUE;
+			}	   
+			return FALSE;
     }
 
-    if (strlen (gtk_entry_get_text (GTK_ENTRY (appGUI->tsk->summary_entry)))) {
+    return FALSE;
+}
+/*------------------------------------------------------------------------------*/
+
+void
+tasks_add_edit_summary_changed_cb (GtkEditable *editable, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+
+    if (strlen (gtk_entry_get_text (GTK_ENTRY (editable)))) {
         appGUI->tsk->tasks_accept_state = TRUE;
     } else {
         appGUI->tsk->tasks_accept_state = FALSE;
     }
-
     gtk_widget_set_sensitive (appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
-
-    return FALSE;
 }
-
 /*------------------------------------------------------------------------------*/
 
 void
@@ -621,6 +640,7 @@ guint id;
 
         gtk_tree_path_free (sort_path);
     }
+
 }
 
 /*------------------------------------------------------------------------------*/
@@ -701,7 +721,9 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_window_set_default_size (GTK_WINDOW(appGUI->tsk->tasks_add_window),
                                  config.tasks_addedit_win_w, config.tasks_addedit_win_h);
 
-    gtk_window_set_transient_for(GTK_WINDOW(appGUI->tsk->tasks_add_window), GTK_WINDOW(appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+        gtk_window_set_transient_for(GTK_WINDOW(appGUI->tsk->tasks_add_window), GTK_WINDOW(appGUI->main_window));
+	}
     gtk_window_set_modal(GTK_WINDOW(appGUI->tsk->tasks_add_window), TRUE);
 
     g_signal_connect (G_OBJECT (appGUI->tsk->tasks_add_window), "key_press_event",
@@ -762,6 +784,8 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
     appGUI->tsk->summary_entry = gtk_entry_new ();
+    g_signal_connect (G_OBJECT (appGUI->tsk->summary_entry), "changed",
+                      G_CALLBACK (tasks_add_edit_summary_changed_cb), appGUI);
     gtk_widget_show (appGUI->tsk->summary_entry);
 
     gtk_table_attach (GTK_TABLE (m_table), appGUI->tsk->summary_entry, 1, 4, 0, 1,
@@ -1406,21 +1430,13 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 16);
 
-    if (config.default_stock_icons) {
-        cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-    } else {
-        cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-    }
+	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 	g_signal_connect (cancel_button, "clicked",
 	                  G_CALLBACK (button_tasks_add_edit_window_close_cb), appGUI);
 
-    if (config.default_stock_icons) {
-        appGUI->tsk->tasks_ok_button = gtk_button_new_from_stock (GTK_STOCK_OK);
-    } else {
-        appGUI->tsk->tasks_ok_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_OK);
-    }
+	appGUI->tsk->tasks_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
     gtk_widget_show (appGUI->tsk->tasks_ok_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->tsk->tasks_ok_button);
 	g_signal_connect (appGUI->tsk->tasks_ok_button, "clicked",
@@ -1575,6 +1591,8 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_widget_set_sensitive(appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
 
     gtk_widget_show(appGUI->tsk->tasks_add_window);
+
+	gtk_widget_grab_focus(appGUI->tsk->summary_entry);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1792,7 +1810,7 @@ xmlChar *escaped;
 
 	doc = xmlNewDoc ((const xmlChar *) "1.0");
 	attr = xmlNewDocProp (doc, (const xmlChar *) "encoding", (const xmlChar *) "utf-8");
-	xmlFree (attr);
+	xmlFreeProp (attr);
 
 	main_node = xmlNewNode (NULL, (const xmlChar *) TASKS_NAME);
 	attr = xmlNewProp (main_node, (const xmlChar *) "version", (const xmlChar *) appGUI->version);
