@@ -32,8 +32,16 @@ enum helpers {
     SOUND
 };
 
+#define     REGEX_HTML      "(http|ftp|https):\\/\\/[\\w\\-_]+(\\.[\\w\\-_]+)+([\\w\\-\\.,@?^=\%&amp;:/~\\+#]*[\\w\\-\\@?^=\%&amp;/~\\+#])?"
+#define     REGEX_URI_PROTO "\\b((http|ftp|https):\\/\\/|(mailto|javascript):)"
+#define     REGEX_EMAIL     "(\\w[-._\\w]*\\w@\\w[-._\\w]*\\w\\.\\w{2,3})"
+
 gchar *     utl_text_replace                    (const gchar *text, const gchar *regex, const gchar *replacement);
-gchar *     utl_text_to_html                    (const gchar *text, gboolean ignoreBR);
+gboolean    utl_text_match                      (const gchar *text, const gchar *regex);
+gchar *     utl_text_to_html_page               (const gchar *text, const gchar *font_family, 
+                                                 const gchar *background_color, const gchar *text_color,
+                                                 const gchar *header_html, const gchar *top_html, const gchar *bottom_html);
+gchar *     utl_text_to_html                    (const gchar *text, gboolean ignoreBR, gboolean ignoreSP);
 gchar *     utl_get_day_name                    (guint day, gboolean short_name);
 gchar *     utl_get_julian_day_name             (guint32 julian);
 gchar *     utl_get_date_name                   (const GDate *date);
@@ -67,8 +75,21 @@ void        utl_cairo_draw                      (cairo_t *cr, gint stroke);
 void        utl_draw_rounded_rectangle          (cairo_t *cr, gint x, gint y, gint w, gint h, gint a, gint s);
 void        utl_draw_left_arrow                 (cairo_t *cr, gdouble x, gdouble y, gdouble w, gdouble h, gdouble a);
 
+gchar *     utl_inline_to_png_base64            (guint8 *inline_data);
+gchar *     utl_inline_image_to_html            (guint8 *inline_data);
+gchar *     utl_text_with_tags_to_html          (gchar *input_text);
+
 void        utl_play_alarm_sound                (guint repetitions);
 gchar *     utl_add_timestamp_to_filename       (gchar *filename, gchar *extension);
+gchar *     utl_strconcat                       (gchar *string, ...);
+
+#ifdef HAVE_LIBWEBKIT
+void        utl_webkit_on_menu                  (WebKitWebView *view, GtkMenu *menu);
+gboolean    utl_webkit_link_clicked             (WebKitWebView *view, WebKitWebFrame *frame,
+                                                 WebKitNetworkRequest *request, 
+                                                 WebKitWebNavigationAction *navigation_action,
+                                                 WebKitWebPolicyDecision *policy_decision);
+#endif  /* HAVE_LIBWEBKIT */
 
 #endif /* _UTILS_H */
 
