@@ -26,9 +26,163 @@
 #include "utils.h"
 #include "utils_gui.h"
 
-static gunichar TAG_CHAR = 0xe000;      /* Unicode chars in the Private Use Area. */
+/* ========================================================================= */
 
-/*------------------------------------------------------------------------------*/
+GtkWidget *
+utl_gui_create_label (const gchar *format, const gchar *name)
+{
+	gchar *str = g_strdup_printf (format, name);
+	GtkWidget *label = gtk_label_new (str);
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	g_free (str);
+
+	return label;
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_window (const gchar *name, gint width, gint height, GUI *appGUI)
+{
+	GtkWidget *window;
+
+	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW (window), name);
+	gtk_window_set_default_size (GTK_WINDOW (window), width, height);
+	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER_ON_PARENT);
+	gtk_window_set_modal (GTK_WINDOW (window), TRUE);
+	if (config.fullscreen == FALSE) {
+		gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (appGUI->main_window));
+	}
+	gtk_container_set_border_width (GTK_CONTAINER (window), WINDOW_BORDER);
+
+	return window;
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_button (const gchar *gtk_name, const gchar *osmo_name, gchar *label)
+{
+	if (config.default_stock_icons) {
+        return gtk_button_new_from_stock (gtk_name);
+	} else {
+		return utl_gui_stock_name_button (osmo_name, label);
+	}
+
+	/*return utl_gui_stock_name_button (config.default_stock_icons ? gtk_name : osmo_name, label);*/
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_frame (GtkWidget *container, const gchar *name)
+{
+	GtkWidget *frame, *label, *alignment;
+
+	frame = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+/*	gtk_container_add (GTK_CONTAINER (container), frame);*/
+	gtk_box_pack_start (GTK_BOX (container), frame, FALSE, FALSE, 0);
+
+	label = utl_gui_create_label ("<b>%s</b>", name);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
+
+	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment),
+	                           ALIGNMENT_PADDING_TOP, ALIGNMENT_PADDING_BOTTOM,
+	                           ALIGNMENT_PADDING_LEFT, ALIGNMENT_PADDING_RIGHT);
+
+	return alignment;
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_vbox_in_frame (GtkWidget *container, const gchar *name)
+{
+	GtkWidget *frame, *box;
+
+	frame = utl_gui_create_frame (container, name);
+
+	box = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (frame), box);
+
+	return box;
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_hbox_in_frame (GtkWidget *container, const gchar *name)
+{
+	GtkWidget *frame, *box;
+
+	frame = utl_gui_create_frame (container, name);
+
+	box = gtk_hbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (frame), box);
+
+	return box;
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_table_in_frame (GtkWidget *container, const gchar *name, guint rows, guint columns)
+{
+	GtkWidget *frame, *table;
+
+	frame = utl_gui_create_frame (container, name);
+
+	table = gtk_table_new (rows, columns, FALSE);
+	gtk_container_add (GTK_CONTAINER (frame), table);
+
+	return table;
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_icon_with_label (const gchar *stock_id, const gchar *label_str)
+{
+	GtkWidget *vbox_icon, *image, *label;
+
+	vbox_icon = gtk_vbox_new (FALSE, 0);
+
+	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_LARGE_TOOLBAR);
+	gtk_box_pack_start (GTK_BOX (vbox_icon), image, TRUE, TRUE, 0);
+
+	label = gtk_label_new (label_str);
+	gtk_box_pack_start (GTK_BOX (vbox_icon), label, FALSE, FALSE, 0);
+	gtk_widget_show_all (vbox_icon);
+
+	return vbox_icon;
+}
+
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_insert_in_scrolled_window (GtkWidget *widget, GtkShadowType type)
+{
+	GtkWidget *scrolledwindow, *viewport;
+
+	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
+	                                GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+
+	viewport = gtk_viewport_new (NULL, NULL);
+	gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport), type);
+	gtk_container_add (GTK_CONTAINER (scrolledwindow), viewport);
+
+	gtk_container_add (GTK_CONTAINER (viewport), widget);
+
+	return scrolledwindow;
+}
+
+/* ========================================================================= */
 
 void
 utl_gui_font_select_cb (GtkWidget *widget, gpointer user_data)
@@ -44,7 +198,9 @@ utl_gui_font_select_cb (GtkWidget *widget, gpointer user_data)
 	font_selector = gtk_font_selection_dialog_new (_("Select a font..."));
 	gtk_window_set_modal (GTK_WINDOW (font_selector), TRUE);
 	gtk_window_set_position (GTK_WINDOW (font_selector), GTK_WIN_POS_MOUSE);
-	gtk_window_set_transient_for (GTK_WINDOW (font_selector), GTK_WINDOW (sel->appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+		gtk_window_set_transient_for (GTK_WINDOW (font_selector), GTK_WINDOW (sel->appGUI->main_window));
+	}
 	gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG (font_selector),
 	                                         sel->config);
 	gtk_widget_show (font_selector);
@@ -165,6 +321,7 @@ GSList *tags = NULL, *i;
 gchar tag_char_utf8[7] = {0};
 gchar *text = g_strdup (""), *oldtext = NULL, *tmp;
 gboolean done = FALSE;
+gunichar TAG_CHAR = TAG;      /* Unicode chars in the Private Use Area. */
 
     gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (buffer), &start);
 
@@ -223,6 +380,7 @@ GList *tags = NULL;
 gchar **tokens;
 gint count;
 gchar tag_char_utf8[7] = {0};
+gunichar TAG_CHAR = TAG;      /* Unicode chars in the Private Use Area. */
 
     if (!text)
         return;
@@ -320,6 +478,7 @@ gchar tag_char_utf8[7] = {0};
 GList *tags = NULL;
 gchar **tokens;
 gint count;
+gunichar TAG_CHAR = TAG;      /* Unicode chars in the Private Use Area. */
 
 	g_return_val_if_fail (output != NULL, NULL);
 
@@ -445,7 +604,7 @@ gint response = -1;
             if (config.default_stock_icons) {
                 info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW(parent), 
                                                       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-                                                      GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message);
+                                                      GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message, NULL);
                 gtk_window_set_title (GTK_WINDOW(info_dialog), _("Question"));
             } else {
                 info_dialog = gtk_dialog_new_with_buttons (_("Question"), GTK_WINDOW(parent),
@@ -460,7 +619,7 @@ gint response = -1;
             if (config.default_stock_icons) {
                 info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW(parent), 
                                                       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-                                                      GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, message);
+                                                      GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, message, NULL);
                 gtk_window_set_title (GTK_WINDOW(info_dialog), _("Information"));
             } else {
                 info_dialog = gtk_dialog_new_with_buttons (_("Information"), GTK_WINDOW(parent),
@@ -474,7 +633,7 @@ gint response = -1;
             if (config.default_stock_icons) {
                 info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW(parent), 
                                                       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-                                                      GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message);
+                                                      GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message, NULL);
                 gtk_window_set_title (GTK_WINDOW(info_dialog), _("Error"));
             } else {
                 info_dialog = gtk_dialog_new_with_buttons (_("Error"), GTK_WINDOW(parent),
@@ -488,7 +647,7 @@ gint response = -1;
             if (config.default_stock_icons) {
                 info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW(parent), 
                                                       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
-                                                      GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, message);
+                                                      GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, message, NULL);
                 gtk_window_set_title (GTK_WINDOW(info_dialog), _("Warning"));
             } else {
                 info_dialog = gtk_dialog_new_with_buttons (_("Warning"), GTK_WINDOW(parent),
@@ -564,14 +723,14 @@ gint response;
 /*------------------------------------------------------------------------------*/
 
 void
-utl_gui_clear_text_buffer (GtkTextBuffer *buffer, GtkTextIter *iter) {
-
-GtkTextIter iter_s, iter_e;
-
-    gtk_text_buffer_get_bounds(buffer, &iter_s, &iter_e);
-    gtk_text_buffer_delete(buffer, &iter_s, &iter_e);  
-    gtk_text_buffer_get_iter_at_offset(buffer, iter, 0);
+utl_gui_clear_text_buffer (GtkTextBuffer *buffer, GtkTextIter *iter)
+{
+	GtkTextIter iter_s, iter_e;
 
+	gtk_text_buffer_get_bounds (buffer, &iter_s, &iter_e);
+	gtk_text_buffer_delete (buffer, &iter_s, &iter_e);
+	if (iter != NULL)
+		gtk_text_buffer_get_iter_at_offset (buffer, iter, 0);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -771,110 +930,55 @@ utl_gui_url_initialize (GUI *appGUI) {
 
 /*------------------------------------------------------------------------------*/
 
-void 
-utl_gui_url_insert_link (GSList *links_list, gint *link_index, GtkWidget *textview, 
-						 GtkTextIter *iter, gchar *color, gchar *font, gchar *text, 
-						 gboolean center, GUI *appGUI) {
+void
+utl_gui_url_insert_link (GSList **links_list, gint *link_index, GtkWidget *textview, GtkTextIter *iter,
+                         gchar *color, gchar *font, gchar *text, gboolean center, GUI *appGUI)
+{
+	GtkJustification justify = center ? GTK_JUSTIFY_CENTER : GTK_JUSTIFY_LEFT;
+	PangoUnderline underline = config.disable_underline_links ? PANGO_UNDERLINE_NONE : PANGO_UNDERLINE_SINGLE;
 
-    if (font == NULL && color == NULL) {
-        if (config.disable_underline_links) {
-            if (center == TRUE) {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", "blue", 
-                                                          "justification", GTK_JUSTIFY_CENTER, NULL);
-            } else {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", "blue", NULL);
-            }
-        } else {
-            if (center == TRUE) {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", "blue", 
-                                                          "underline", PANGO_UNDERLINE_SINGLE,
-                                                          "justification", GTK_JUSTIFY_CENTER, NULL);
-            } else {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", "blue", 
-                                                          "underline", PANGO_UNDERLINE_SINGLE, NULL);
-            }
-        }
-    } else {
-        if (config.disable_underline_links) {
-            if (center == TRUE) {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", color, 
-                                                          "font", font,
-                                                          "justification", GTK_JUSTIFY_CENTER, NULL);
-            } else {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", color, 
-                                                          "font", font, NULL);
-            }
-        } else {
-            if (center == TRUE) {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", color, 
-                                                          "underline", PANGO_UNDERLINE_SINGLE, 
-                                                          "font", font,
-                                                          "justification", GTK_JUSTIFY_CENTER, NULL);
-            } else {
-                appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)),
-                                                          NULL, "foreground", color, 
-                                                          "underline", PANGO_UNDERLINE_SINGLE, 
-                                                          "font", font, NULL);
-            }
-        }
-    }
+	appGUI->gui_url_tag = gtk_text_buffer_create_tag (gtk_text_view_get_buffer (GTK_TEXT_VIEW (textview)), NULL,
+	                                                  "foreground", color,
+	                                                  "font", font,
+	                                                  "justification", justify,
+	                                                  "underline", underline,
+	                                                  NULL);
 
-    g_object_set_data (G_OBJECT (appGUI->gui_url_tag), "link", GINT_TO_POINTER (*link_index));
+	g_object_set_data (G_OBJECT (appGUI->gui_url_tag), "link", GINT_TO_POINTER (*link_index));
 
-    links_list = g_slist_append (links_list, g_strdup(text));
-    gtk_text_buffer_insert_with_tags (gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview)), 
-                                      iter, text, -1, appGUI->gui_url_tag, NULL);
-    (*link_index)++;
+	*links_list = g_slist_append (*links_list, g_strdup (text));
+	gtk_text_buffer_insert_with_tags (gtk_text_view_get_buffer (GTK_TEXT_VIEW (textview)),
+	                                  iter, text, -1, appGUI->gui_url_tag, NULL);
+	(*link_index)++;
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-utl_gui_url_remove_links (GSList *links_list, gint *link_index) {
+utl_gui_url_remove_links (GSList **links_list, gint *link_index)
+{
+	if (link_index) *link_index = 1;
 
-gint i;
-gchar *link;
-GSList *lnode;
-
-        *link_index = 1;
-
-        if (links_list != NULL) {
-
-            for (i = 0, lnode = links_list; lnode != NULL; lnode = lnode->next, i++) {
-                link = g_slist_nth_data (links_list, i);
-                if (link != NULL) {
-                    g_free(link);
-                }
-            }
-
-            for (i = 0, lnode = links_list; lnode != NULL; lnode = lnode->next, i++) {
-                links_list = g_slist_remove_link (links_list, g_slist_nth(links_list, i));
-            }
-
-        }
+	if (*links_list != NULL) {
+		g_slist_foreach (*links_list, (GFunc) g_free, NULL);
+		g_slist_free (*links_list);
+		*links_list = NULL;
+	}
 }
 
-
 /*------------------------------------------------------------------------------*/
 
 void
 utl_gui_url_set_cursor_if_appropriate (GtkTextView *textview, gint x, gint y, GUI *appGUI) {
 
 GSList *tags = NULL, *tagp = NULL;
-GtkTextBuffer *buffer;
+/*GtkTextBuffer *buffer;*/
 GtkTextIter iter;
 gboolean hovering = FALSE;
 GtkTextTag *tag;
 int *slink;
 
-    buffer = gtk_text_view_get_buffer (textview);
+/*    buffer = gtk_text_view_get_buffer (textview);*/
 
     gtk_text_view_get_iter_at_location (textview, &iter, x, y);
 
@@ -908,60 +1012,50 @@ int *slink;
 /*------------------------------------------------------------------------------*/
 
 gboolean
-utl_gui_url_event_after (GtkWidget *textview, GdkEvent *ev, GSList *links_list) {
+utl_gui_url_event_after (GtkWidget *textview, GdkEvent *ev, GSList **links_list)
+{
+	GtkTextIter start, end, iter;
+	GtkTextBuffer *buffer;
+	GdkEventButton *event;
+	gint x, y;
+	GSList *tags = NULL, *tagp = NULL;
+	GtkTextTag *tag;
+	gchar *link;
+	gint slink;
+	gchar tmpbuf[BUFFER_SIZE];
 
-GtkTextIter start, end, iter;
-GtkTextBuffer *buffer;
-GdkEventButton *event;
-gint x, y;
-GSList *tags = NULL, *tagp = NULL;
-GtkTextTag *tag;
-gchar *link;
-gint slink;
-gchar tmpbuf[BUFFER_SIZE];
+	if (ev->type != GDK_BUTTON_RELEASE)
+		return FALSE;
 
-    if (ev->type != GDK_BUTTON_RELEASE) {
-        return FALSE;
-    }
+	event = (GdkEventButton *) ev;
+	if (event->button != 1)
+		return FALSE;
 
-    event = (GdkEventButton *)ev;
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (textview));
+	gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
+	if (gtk_text_iter_get_offset (&start) != gtk_text_iter_get_offset (&end))
+		return FALSE;
 
-    if (event->button != 1) {
-        return FALSE;
-    }
+	gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (textview), GTK_TEXT_WINDOW_WIDGET,
+	                                       event->x, event->y, &x, &y);
+	gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (textview), &iter, x, y);
 
-    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (textview));
+	tags = gtk_text_iter_get_tags (&iter);
+	for (tagp = tags; tagp != NULL; tagp = tagp->next) {
+		tag = tagp->data;
+		slink = (size_t) g_object_get_data (G_OBJECT (tag), "link");
 
-    gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
-    if (gtk_text_iter_get_offset (&start) != gtk_text_iter_get_offset (&end)) {
-        return FALSE;
-    }
-
-    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (textview), GTK_TEXT_WINDOW_WIDGET, 
-                                           event->x, event->y, &x, &y);
-    gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (textview), &iter, x, y);
-
-    tags = gtk_text_iter_get_tags (&iter);
-
-    for (tagp = tags;  tagp != NULL;  tagp = tagp->next) {
-
-        tag = tagp->data;
-        slink = (gint) g_object_get_data (G_OBJECT (tag), "link");
-
-
-        if (slink != 0) {
-            link = g_slist_nth_data (links_list, slink);
+		if (slink != 0) {
+			link = g_slist_nth_data (*links_list, slink-1);
 			g_snprintf (tmpbuf, BUFFER_SIZE, "\"%s\"", link);
-            utl_run_helper(tmpbuf, utl_get_link_type(link));
-            break;
-        }
-    }
+			utl_run_helper (tmpbuf, utl_get_link_type (link));
+			break;
+		}
+	}
 
-    if (tags) {
-        g_slist_free (tags);
-    }
+	if (tags) g_slist_free (tags);
 
-    return FALSE;
+	return FALSE;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -998,7 +1092,7 @@ gint wx, wy, bx, by;
 /*------------------------------------------------------------------------------*/
 
 void
-utl_gui_url_setup (GSList *links_list, gint *link_index, GtkWidget *textview, GUI *appGUI) {
+utl_gui_url_setup (GSList **links_list, gint *link_index, GtkWidget *textview, GUI *appGUI) {
 
     utl_gui_url_remove_links (links_list, link_index);
 
